Class: Aws::Neptune::Types::AddRoleToDBClusterMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_cluster_identifierString

The name of the DB cluster to associate the IAM role with.



31
32
33
34
35
36
37
# File 'lib/aws-sdk-neptune/types.rb', line 31

class AddRoleToDBClusterMessage < Struct.new(
  :db_cluster_identifier,
  :role_arn,
  :feature_name)
  SENSITIVE = []
  include Aws::Structure
end

#feature_nameString

The name of the feature for the Neptune DB cluster that the IAM role is to be associated with. For the list of supported feature names, see DBEngineVersion.



31
32
33
34
35
36
37
# File 'lib/aws-sdk-neptune/types.rb', line 31

class AddRoleToDBClusterMessage < Struct.new(
  :db_cluster_identifier,
  :role_arn,
  :feature_name)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role to associate with the Neptune DB cluster, for example arn:aws:iam::123456789012:role/NeptuneAccessRole.



31
32
33
34
35
36
37
# File 'lib/aws-sdk-neptune/types.rb', line 31

class AddRoleToDBClusterMessage < Struct.new(
  :db_cluster_identifier,
  :role_arn,
  :feature_name)
  SENSITIVE = []
  include Aws::Structure
end