Class: Aws::Neptune::Types::ClusterPendingModifiedValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::ClusterPendingModifiedValues
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
This data type is used as a response element in the ‘ModifyDBCluster` operation and contains changes that will be applied during the next maintenance window.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The allocated storage size in gibibytes (GiB) for database engines.
-
#backup_retention_period ⇒ Integer
The number of days for which automatic DB snapshots are retained.
-
#db_cluster_identifier ⇒ String
The DBClusterIdentifier value for the DB cluster.
-
#engine_version ⇒ String
The database engine version.
-
#iam_database_authentication_enabled ⇒ Boolean
A value that indicates whether mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled.
-
#iops ⇒ Integer
The Provisioned IOPS (I/O operations per second) value.
-
#network_type ⇒ String
The pending change in network type for the DB cluster.
-
#pending_cloudwatch_logs_exports ⇒ Types::PendingCloudwatchLogsExports
This ‘PendingCloudwatchLogsExports` structure specifies pending changes to which CloudWatch logs are enabled and which are disabled.
-
#storage_type ⇒ String
The pending change in storage type for the DB cluster.
Instance Attribute Details
#allocated_storage ⇒ Integer
The allocated storage size in gibibytes (GiB) for database engines. For Neptune, ‘AllocatedStorage` always returns 1, because Neptune DB cluster storage size isn’t fixed, but instead automatically adjusts as needed.
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-neptune/types.rb', line 309 class ClusterPendingModifiedValues < Struct.new( :pending_cloudwatch_logs_exports, :db_cluster_identifier, :iam_database_authentication_enabled, :engine_version, :backup_retention_period, :storage_type, :allocated_storage, :iops, :network_type) SENSITIVE = [] include Aws::Structure end |
#backup_retention_period ⇒ Integer
The number of days for which automatic DB snapshots are retained.
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-neptune/types.rb', line 309 class ClusterPendingModifiedValues < Struct.new( :pending_cloudwatch_logs_exports, :db_cluster_identifier, :iam_database_authentication_enabled, :engine_version, :backup_retention_period, :storage_type, :allocated_storage, :iops, :network_type) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
The DBClusterIdentifier value for the DB cluster.
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-neptune/types.rb', line 309 class ClusterPendingModifiedValues < Struct.new( :pending_cloudwatch_logs_exports, :db_cluster_identifier, :iam_database_authentication_enabled, :engine_version, :backup_retention_period, :storage_type, :allocated_storage, :iops, :network_type) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The database engine version.
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-neptune/types.rb', line 309 class ClusterPendingModifiedValues < Struct.new( :pending_cloudwatch_logs_exports, :db_cluster_identifier, :iam_database_authentication_enabled, :engine_version, :backup_retention_period, :storage_type, :allocated_storage, :iops, :network_type) SENSITIVE = [] include Aws::Structure end |
#iam_database_authentication_enabled ⇒ Boolean
A value that indicates whether mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled.
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-neptune/types.rb', line 309 class ClusterPendingModifiedValues < Struct.new( :pending_cloudwatch_logs_exports, :db_cluster_identifier, :iam_database_authentication_enabled, :engine_version, :backup_retention_period, :storage_type, :allocated_storage, :iops, :network_type) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The Provisioned IOPS (I/O operations per second) value. This setting is only for Multi-AZ DB clusters.
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-neptune/types.rb', line 309 class ClusterPendingModifiedValues < Struct.new( :pending_cloudwatch_logs_exports, :db_cluster_identifier, :iam_database_authentication_enabled, :engine_version, :backup_retention_period, :storage_type, :allocated_storage, :iops, :network_type) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
The pending change in network type for the DB cluster.
Valid Values: ‘IPV4`, `DUAL`
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-neptune/types.rb', line 309 class ClusterPendingModifiedValues < Struct.new( :pending_cloudwatch_logs_exports, :db_cluster_identifier, :iam_database_authentication_enabled, :engine_version, :backup_retention_period, :storage_type, :allocated_storage, :iops, :network_type) SENSITIVE = [] include Aws::Structure end |
#pending_cloudwatch_logs_exports ⇒ Types::PendingCloudwatchLogsExports
This ‘PendingCloudwatchLogsExports` structure specifies pending changes to which CloudWatch logs are enabled and which are disabled.
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-neptune/types.rb', line 309 class ClusterPendingModifiedValues < Struct.new( :pending_cloudwatch_logs_exports, :db_cluster_identifier, :iam_database_authentication_enabled, :engine_version, :backup_retention_period, :storage_type, :allocated_storage, :iops, :network_type) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The pending change in storage type for the DB cluster. Valid Values:
-
standard– ( *the default* ) Configures cost-effective database storage for applications with moderate to small I/O usage. -
iopt1– Enables [I/O-Optimized storage] that’s designed to meet the needs of I/O-intensive graph workloads that require predictable pricing with low I/O latency and consistent I/O throughput.Neptune I/O-Optimized storage is only available starting with engine release 1.3.0.0.
[1]: docs.aws.amazon.com/neptune/latest/userguide/storage-types.html#provisioned-iops-storage
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/aws-sdk-neptune/types.rb', line 309 class ClusterPendingModifiedValues < Struct.new( :pending_cloudwatch_logs_exports, :db_cluster_identifier, :iam_database_authentication_enabled, :engine_version, :backup_retention_period, :storage_type, :allocated_storage, :iops, :network_type) SENSITIVE = [] include Aws::Structure end |