Class: Aws::Neptune::Types::CopyDBClusterParameterGroupMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#source_db_cluster_parameter_group_identifierString

The identifier or Amazon Resource Name (ARN) for the source DB cluster parameter group. For information about creating an ARN, see [ Constructing an Amazon Resource Name (ARN)].

Constraints:

  • Must specify a valid DB cluster parameter group.

  • Must specify a valid DB cluster parameter group identifier, for example ‘my-db-cluster-param-group`, or a valid ARN.

  • The source DB cluster parameter group must be in the same Amazon Region as the copy. Neptune does not support cross-Region copying of parameter groups.

[1]: docs.aws.amazon.com/neptune/latest/UserGuide/tagging.ARN.html#tagging.ARN.Constructing

Returns:

  • (String)


370
371
372
373
374
375
376
377
# File 'lib/aws-sdk-neptune/types.rb', line 370

class CopyDBClusterParameterGroupMessage < Struct.new(
  :source_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags to be assigned to the copied DB cluster parameter group.

Returns:



370
371
372
373
374
375
376
377
# File 'lib/aws-sdk-neptune/types.rb', line 370

class CopyDBClusterParameterGroupMessage < Struct.new(
  :source_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_db_cluster_parameter_group_descriptionString

A description for the copied DB cluster parameter group.

Returns:

  • (String)


370
371
372
373
374
375
376
377
# File 'lib/aws-sdk-neptune/types.rb', line 370

class CopyDBClusterParameterGroupMessage < Struct.new(
  :source_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_db_cluster_parameter_group_identifierString

The identifier for the copied DB cluster parameter group.

Constraints:

  • Cannot be null, empty, or blank

  • Must contain from 1 to 255 letters, numbers, or hyphens

  • First character must be a letter

  • Cannot end with a hyphen or contain two consecutive hyphens

Example: ‘my-cluster-param-group1`

Returns:

  • (String)


370
371
372
373
374
375
376
377
# File 'lib/aws-sdk-neptune/types.rb', line 370

class CopyDBClusterParameterGroupMessage < Struct.new(
  :source_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end