Class: Aws::Neptune::Types::CreateDBClusterEndpointMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_cluster_endpoint_identifierString

The identifier to use for the new endpoint. This parameter is stored as a lowercase string.

Returns:

  • (String)


600
601
602
603
604
605
606
607
608
609
# File 'lib/aws-sdk-neptune/types.rb', line 600

class CreateDBClusterEndpointMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_identifierString

The DB cluster identifier of the DB cluster associated with the endpoint. This parameter is stored as a lowercase string.

Returns:

  • (String)


600
601
602
603
604
605
606
607
608
609
# File 'lib/aws-sdk-neptune/types.rb', line 600

class CreateDBClusterEndpointMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_typeString

The type of the endpoint. One of: ‘READER`, `WRITER`, `ANY`.

Returns:

  • (String)


600
601
602
603
604
605
606
607
608
609
# File 'lib/aws-sdk-neptune/types.rb', line 600

class CreateDBClusterEndpointMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#excluded_membersArray<String>

List of DB instance identifiers that aren’t part of the custom endpoint group. All other eligible instances are reachable through the custom endpoint. Only relevant if the list of static members is empty.

Returns:

  • (Array<String>)


600
601
602
603
604
605
606
607
608
609
# File 'lib/aws-sdk-neptune/types.rb', line 600

class CreateDBClusterEndpointMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#static_membersArray<String>

List of DB instance identifiers that are part of the custom endpoint group.

Returns:

  • (Array<String>)


600
601
602
603
604
605
606
607
608
609
# File 'lib/aws-sdk-neptune/types.rb', line 600

class CreateDBClusterEndpointMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags to be assigned to the Amazon Neptune resource.

Returns:



600
601
602
603
604
605
606
607
608
609
# File 'lib/aws-sdk-neptune/types.rb', line 600

class CreateDBClusterEndpointMessage < Struct.new(
  :db_cluster_identifier,
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end