Class: Aws::Neptune::Types::CreateDBClusterMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::CreateDBClusterMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<String>
A list of EC2 Availability Zones that instances in the DB cluster can be created in.
-
#backup_retention_period ⇒ Integer
The number of days for which automated backups are retained.
-
#character_set_name ⇒ String
*(Not supported by Neptune)*.
-
#copy_tags_to_snapshot ⇒ Boolean
*If set to ‘true`, tags are copied to any snapshot of the DB cluster that is created.*.
-
#database_name ⇒ String
Not supported by Neptune.
-
#db_cluster_identifier ⇒ String
The DB cluster identifier.
-
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group to associate with this DB cluster.
-
#db_subnet_group_name ⇒ String
A DB subnet group to associate with this DB cluster.
-
#deletion_protection ⇒ Boolean
A value that indicates whether the DB cluster has deletion protection enabled.
-
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of the log types that this DB cluster should export to CloudWatch Logs.
-
#enable_iam_database_authentication ⇒ Boolean
If set to ‘true`, enables Amazon Identity and Access Management (IAM) authentication for the entire DB cluster (this cannot be set at an instance level).
-
#engine ⇒ String
The name of the database engine to be used for this DB cluster.
-
#engine_version ⇒ String
The version number of the database engine to use for the new DB cluster.
-
#global_cluster_identifier ⇒ String
The ID of the Neptune global database to which this new DB cluster should be added.
-
#kms_key_id ⇒ String
The Amazon KMS key identifier for an encrypted DB cluster.
-
#master_user_password ⇒ String
Not supported by Neptune.
-
#master_username ⇒ String
Not supported by Neptune.
-
#network_type ⇒ String
The network type of the DB cluster.
-
#option_group_name ⇒ String
*(Not supported by Neptune)*.
-
#port ⇒ Integer
The port number on which the instances in the DB cluster accept connections.
-
#pre_signed_url ⇒ String
This parameter is not currently supported.
-
#preferred_backup_window ⇒ String
The daily time range during which automated backups are created if automated backups are enabled using the ‘BackupRetentionPeriod` parameter.
-
#preferred_maintenance_window ⇒ String
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
-
#replication_source_identifier ⇒ String
The Amazon Resource Name (ARN) of the source DB instance or DB cluster if this DB cluster is created as a Read Replica.
-
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfiguration
Contains the scaling configuration of a Neptune Serverless DB cluster.
-
#source_region ⇒ String
The source region of the snapshot.
-
#storage_encrypted ⇒ Boolean
Specifies whether the DB cluster is encrypted.
-
#storage_type ⇒ String
The storage type for the new DB cluster.
-
#tags ⇒ Array<Types::Tag>
The tags to assign to the new DB cluster.
-
#vpc_security_group_ids ⇒ Array<String>
A list of EC2 VPC security groups to associate with this DB cluster.
Instance Attribute Details
#availability_zones ⇒ Array<String>
A list of EC2 Availability Zones that instances in the DB cluster can be created in.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#backup_retention_period ⇒ Integer
The number of days for which automated backups are retained. You must specify a minimum value of 1.
Default: 1
Constraints:
-
Must be a value from 1 to 35
^
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#character_set_name ⇒ String
*(Not supported by Neptune)*
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#copy_tags_to_snapshot ⇒ Boolean
*If set to ‘true`, tags are copied to any snapshot of the DB cluster that is created.*
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
Not supported by Neptune.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
The DB cluster identifier. This parameter is stored as a lowercase string.
Constraints:
-
Must contain from 1 to 63 letters, numbers, or hyphens.
-
First character must be a letter.
-
Cannot end with a hyphen or contain two consecutive hyphens.
Example: ‘my-cluster1`
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group to associate with this DB cluster. If this argument is omitted, the default is used.
Constraints:
-
If supplied, must match the name of an existing DBClusterParameterGroup.
^
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#db_subnet_group_name ⇒ String
A DB subnet group to associate with this DB cluster.
Constraints: Must match the name of an existing DBSubnetGroup. Must not be default.
Example: ‘mySubnetgroup`
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ Boolean
A value that indicates whether the DB cluster has deletion protection enabled. The database can’t be deleted when deletion protection is enabled. By default, deletion protection is enabled.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#enable_cloudwatch_logs_exports ⇒ Array<String>
A list of the log types that this DB cluster should export to CloudWatch Logs. Valid log types are: ‘audit` (to publish audit logs) and `slowquery` (to publish slow-query logs). See [Publishing Neptune logs to Amazon CloudWatch logs].
[1]: docs.aws.amazon.com/neptune/latest/userguide/cloudwatch-logs.html
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#enable_iam_database_authentication ⇒ Boolean
If set to ‘true`, enables Amazon Identity and Access Management (IAM) authentication for the entire DB cluster (this cannot be set at an instance level).
Default: ‘false`.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the database engine to be used for this DB cluster.
Valid Values: ‘neptune`
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version number of the database engine to use for the new DB cluster.
Example: ‘1.2.1.0`
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#global_cluster_identifier ⇒ String
The ID of the Neptune global database to which this new DB cluster should be added.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon KMS key identifier for an encrypted DB cluster.
The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are creating a DB cluster with the same Amazon account that owns the KMS encryption key used to encrypt the new DB cluster, then you can use the KMS key alias instead of the ARN for the KMS encryption key.
If an encryption key is not specified in ‘KmsKeyId`:
-
If ‘ReplicationSourceIdentifier` identifies an encrypted source, then Amazon Neptune will use the encryption key used to encrypt the source. Otherwise, Amazon Neptune will use your default encryption key.
-
If the ‘StorageEncrypted` parameter is true and `ReplicationSourceIdentifier` is not specified, then Amazon Neptune will use your default encryption key.
Amazon KMS creates the default encryption key for your Amazon account. Your Amazon account has a different default encryption key for each Amazon Region.
If you create a Read Replica of an encrypted DB cluster in another Amazon Region, you must set ‘KmsKeyId` to a KMS key ID that is valid in the destination Amazon Region. This key is used to encrypt the Read Replica in that Amazon Region.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#master_user_password ⇒ String
Not supported by Neptune.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#master_username ⇒ String
Not supported by Neptune.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
The network type of the DB cluster.
Valid Values:
-
IPV4– ( *the default* ) The DB cluster uses only IPv4 addresses for communication. -
DUAL– The DB cluster uses both IPv4 and IPv6 addresses for communication. The DB subnet group associated with the cluster must support IPv6.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#option_group_name ⇒ String
*(Not supported by Neptune)*
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which the instances in the DB cluster accept connections.
Default: ‘8182`
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#pre_signed_url ⇒ String
This parameter is not currently supported.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#preferred_backup_window ⇒ String
The daily time range during which automated backups are created if automated backups are enabled using the ‘BackupRetentionPeriod` parameter.
The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Region. To see the time blocks available, see [Neptune Maintenance Window] in the *Amazon Neptune User Guide.*
Constraints:
-
Must be in the format ‘hh24:mi-hh24:mi`.
-
Must be in Universal Coordinated Time (UTC).
-
Must not conflict with the preferred maintenance window.
-
Must be at least 30 minutes.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#preferred_maintenance_window ⇒ String
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
Format: ‘ddd:hh24:mi-ddd:hh24:mi`
The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Region, occurring on a random day of the week. To see the time blocks available, see [Neptune Maintenance Window] in the *Amazon Neptune User Guide.*
Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun.
Constraints: Minimum 30-minute window.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#replication_source_identifier ⇒ String
The Amazon Resource Name (ARN) of the source DB instance or DB cluster if this DB cluster is created as a Read Replica.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfiguration
Contains the scaling configuration of a Neptune Serverless DB cluster.
For more information, see [Using Amazon Neptune Serverless] in the *Amazon Neptune User Guide*.
[1]: docs.aws.amazon.com/neptune/latest/userguide/neptune-serverless-using.html
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#source_region ⇒ String
The source region of the snapshot. This is only needed when the shapshot is encrypted and in a different region.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#storage_encrypted ⇒ Boolean
Specifies whether the DB cluster is encrypted.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The storage type for the new DB cluster.
Valid Values:
-
standard– ( *the default* ) Configures cost-effective database storage for applications with moderate to small I/O usage. When set to ‘standard`, the storage type is not returned in the response. -
iopt1– Enables [I/O-Optimized storage] that’s designed to meet the needs of I/O-intensive graph workloads that require predictable pricing with low I/O latency and consistent I/O throughput.Neptune I/O-Optimized storage is only available starting with engine release 1.3.0.0.
[1]: docs.aws.amazon.com/neptune/latest/userguide/storage-types.html#provisioned-iops-storage
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to assign to the new DB cluster.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of EC2 VPC security groups to associate with this DB cluster.
975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-neptune/types.rb', line 975 class CreateDBClusterMessage < Struct.new( :availability_zones, :backup_retention_period, :character_set_name, :copy_tags_to_snapshot, :database_name, :db_cluster_identifier, :db_cluster_parameter_group_name, :vpc_security_group_ids, :db_subnet_group_name, :engine, :engine_version, :port, :master_username, :master_user_password, :option_group_name, :preferred_backup_window, :preferred_maintenance_window, :replication_source_identifier, :tags, :storage_encrypted, :kms_key_id, :pre_signed_url, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :deletion_protection, :serverless_v2_scaling_configuration, :global_cluster_identifier, :storage_type, :network_type, :source_region) SENSITIVE = [] include Aws::Structure end |