Class: Aws::Neptune::Types::DBEngineVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::DBEngineVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
This data type is used as a response element in the action DescribeDBEngineVersions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_engine_description ⇒ String
The description of the database engine.
-
#db_engine_version_description ⇒ String
The description of the database engine version.
-
#db_parameter_group_family ⇒ String
The name of the DB parameter group family for the database engine.
-
#default_character_set ⇒ Types::CharacterSet
*(Not supported by Neptune)*.
-
#engine ⇒ String
The name of the database engine.
-
#engine_version ⇒ String
The version number of the database engine.
-
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to CloudWatch Logs.
-
#supported_character_sets ⇒ Array<Types::CharacterSet>
*(Not supported by Neptune)*.
-
#supported_timezones ⇒ Array<Types::Timezone>
A list of the time zones supported by this engine for the ‘Timezone` parameter of the `CreateDBInstance` action.
-
#supports_global_databases ⇒ Boolean
A value that indicates whether you can use Aurora global databases with a specific DB engine version.
-
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
A value that indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.
-
#supports_read_replica ⇒ Boolean
Indicates whether the database engine version supports read replicas.
-
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
Instance Attribute Details
#db_engine_description ⇒ String
The description of the database engine.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#db_engine_version_description ⇒ String
The description of the database engine version.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#db_parameter_group_family ⇒ String
The name of the DB parameter group family for the database engine.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#default_character_set ⇒ Types::CharacterSet
*(Not supported by Neptune)*
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the database engine.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version number of the database engine.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to CloudWatch Logs.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supported_character_sets ⇒ Array<Types::CharacterSet>
*(Not supported by Neptune)*
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supported_timezones ⇒ Array<Types::Timezone>
A list of the time zones supported by this engine for the ‘Timezone` parameter of the `CreateDBInstance` action.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supports_global_databases ⇒ Boolean
A value that indicates whether you can use Aurora global databases with a specific DB engine version.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
A value that indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supports_read_replica ⇒ Boolean
Indicates whether the database engine version supports read replicas.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 |
# File 'lib/aws-sdk-neptune/types.rb', line 2810 class DBEngineVersion < Struct.new( :engine, :engine_version, :db_parameter_group_family, :db_engine_description, :db_engine_version_description, :default_character_set, :supported_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |