Class: Aws::Neptune::Types::DBInstanceStatusInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::DBInstanceStatusInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Provides a list of status information for a DB instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Details of the error if there is an error for the instance.
-
#normal ⇒ Boolean
Boolean value that is true if the instance is operating normally, or false if the instance is in an error state.
-
#status ⇒ String
Status of the DB instance.
-
#status_type ⇒ String
This value is currently “read replication.”.
Instance Attribute Details
#message ⇒ String
Details of the error if there is an error for the instance. If the instance is not in an error state, this value is blank.
3200 3201 3202 3203 3204 3205 3206 3207 |
# File 'lib/aws-sdk-neptune/types.rb', line 3200 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |
#normal ⇒ Boolean
Boolean value that is true if the instance is operating normally, or false if the instance is in an error state.
3200 3201 3202 3203 3204 3205 3206 3207 |
# File 'lib/aws-sdk-neptune/types.rb', line 3200 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of the DB instance. For a StatusType of read replica, the values can be replicating, error, stopped, or terminated.
3200 3201 3202 3203 3204 3205 3206 3207 |
# File 'lib/aws-sdk-neptune/types.rb', line 3200 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |
#status_type ⇒ String
This value is currently “read replication.”
3200 3201 3202 3203 3204 3205 3206 3207 |
# File 'lib/aws-sdk-neptune/types.rb', line 3200 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |