Class: Aws::Neptune::Types::DBSubnetGroupMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_subnet_groupsArray<Types::DBSubnetGroup>

A list of DBSubnetGroup instances.



3446
3447
3448
3449
3450
3451
# File 'lib/aws-sdk-neptune/types.rb', line 3446

class DBSubnetGroupMessage < Struct.new(
  :marker,
  :db_subnet_groups)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



3446
3447
3448
3449
3450
3451
# File 'lib/aws-sdk-neptune/types.rb', line 3446

class DBSubnetGroupMessage < Struct.new(
  :marker,
  :db_subnet_groups)
  SENSITIVE = []
  include Aws::Structure
end