Class: Aws::Neptune::Types::DeleteDBClusterEndpointOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

This data type represents the information you need to connect to an Amazon Neptune DB cluster. This data type is used as a response element in the following actions:

  • CreateDBClusterEndpoint

  • DescribeDBClusterEndpoints

  • ModifyDBClusterEndpoint

  • DeleteDBClusterEndpoint

For the data structure that represents Amazon RDS DB instance endpoints, see Endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_endpoint_typeString

The type associated with a custom endpoint. One of: READER, WRITER, ANY.

Returns:

  • (String)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_endpoint_arnString

The Amazon Resource Name (ARN) for the endpoint.

Returns:

  • (String)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_endpoint_identifierString

The identifier associated with the endpoint. This parameter is stored as a lowercase string.

Returns:

  • (String)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_endpoint_resource_identifierString

A unique system-generated identifier for an endpoint. It remains the same for the whole life of the endpoint.

Returns:

  • (String)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_identifierString

The DB cluster identifier of the DB cluster associated with the endpoint. This parameter is stored as a lowercase string.

Returns:

  • (String)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The DNS address of the endpoint.

Returns:

  • (String)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_typeString

The type of the endpoint. One of: READER, WRITER, CUSTOM.

Returns:

  • (String)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end

#excluded_membersArray<String>

List of DB instance identifiers that aren’t part of the custom endpoint group. All other eligible instances are reachable through the custom endpoint. Only relevant if the list of static members is empty.

Returns:

  • (Array<String>)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end

#static_membersArray<String>

List of DB instance identifiers that are part of the custom endpoint group.

Returns:

  • (Array<String>)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the endpoint. One of: creating, available, deleting, inactive, modifying. The inactive state applies to an endpoint that cannot be used for a certain kind of cluster, such as a writer endpoint for a read-only secondary cluster in a global database.

Returns:

  • (String)


3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-neptune/types.rb', line 3562

class DeleteDBClusterEndpointOutput < Struct.new(
  :db_cluster_endpoint_identifier,
  :db_cluster_identifier,
  :db_cluster_endpoint_resource_identifier,
  :endpoint,
  :status,
  :endpoint_type,
  :custom_endpoint_type,
  :static_members,
  :excluded_members,
  :db_cluster_endpoint_arn)
  SENSITIVE = []
  include Aws::Structure
end