Class: Aws::Neptune::Types::DescribeDBClusterParametersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::DescribeDBClusterParametersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_cluster_parameter_group_name ⇒ String
The name of a specific DB cluster parameter group to return parameter details for.
-
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBClusterParametersrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#source ⇒ String
A value that indicates to return only parameters for a specific source.
Instance Attribute Details
#db_cluster_parameter_group_name ⇒ String
The name of a specific DB cluster parameter group to return parameter details for.
Constraints:
-
If supplied, must match the name of an existing DBClusterParameterGroup.
^
4011 4012 4013 4014 4015 4016 4017 4018 4019 |
# File 'lib/aws-sdk-neptune/types.rb', line 4011 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
4011 4012 4013 4014 4015 4016 4017 4018 4019 |
# File 'lib/aws-sdk-neptune/types.rb', line 4011 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeDBClusterParameters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
4011 4012 4013 4014 4015 4016 4017 4018 4019 |
# File 'lib/aws-sdk-neptune/types.rb', line 4011 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
4011 4012 4013 4014 4015 4016 4017 4018 4019 |
# File 'lib/aws-sdk-neptune/types.rb', line 4011 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
A value that indicates to return only parameters for a specific source. Parameter sources can be engine, service, or customer.
4011 4012 4013 4014 4015 4016 4017 4018 4019 |
# File 'lib/aws-sdk-neptune/types.rb', line 4011 class DescribeDBClusterParametersMessage < Struct.new( :db_cluster_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |