Class: Aws::Neptune::Types::DescribeDBEngineVersionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_parameter_group_familyString

The name of a specific DB parameter group family to return details for.

Constraints:

  • If supplied, must match an existing DBParameterGroupFamily.

^



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
# File 'lib/aws-sdk-neptune/types.rb', line 4285

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  SENSITIVE = []
  include Aws::Structure
end

#default_onlyBoolean

Indicates that only the default version of the specified engine or engine and major version combination is returned.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
# File 'lib/aws-sdk-neptune/types.rb', line 4285

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The database engine to return.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
# File 'lib/aws-sdk-neptune/types.rb', line 4285

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The database engine version to return.

Example: 5.1.49



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
# File 'lib/aws-sdk-neptune/types.rb', line 4285

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Not currently supported.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
# File 'lib/aws-sdk-neptune/types.rb', line 4285

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  SENSITIVE = []
  include Aws::Structure
end

#list_supported_character_setsBoolean

If this parameter is specified and the requested engine supports the CharacterSetName parameter for CreateDBInstance, the response includes a list of supported character sets for each engine version.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
# File 'lib/aws-sdk-neptune/types.rb', line 4285

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  SENSITIVE = []
  include Aws::Structure
end

#list_supported_timezonesBoolean

If this parameter is specified and the requested engine supports the TimeZone parameter for CreateDBInstance, the response includes a list of supported time zones for each engine version.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
# File 'lib/aws-sdk-neptune/types.rb', line 4285

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
# File 'lib/aws-sdk-neptune/types.rb', line 4285

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so that the following results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
# File 'lib/aws-sdk-neptune/types.rb', line 4285

class DescribeDBEngineVersionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker,
  :default_only,
  :list_supported_character_sets,
  :list_supported_timezones)
  SENSITIVE = []
  include Aws::Structure
end