Class: Aws::Neptune::Types::DescribeDBParameterGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::DescribeDBParameterGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_parameter_group_name ⇒ String
The name of a specific DB parameter group to return details for.
-
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBParameterGroupsrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_parameter_group_name ⇒ String
The name of a specific DB parameter group to return details for.
Constraints:
-
If supplied, must match the name of an existing DBClusterParameterGroup.
^
4393 4394 4395 4396 4397 4398 4399 4400 |
# File 'lib/aws-sdk-neptune/types.rb', line 4393 class DescribeDBParameterGroupsMessage < Struct.new( :db_parameter_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
4393 4394 4395 4396 4397 4398 4399 4400 |
# File 'lib/aws-sdk-neptune/types.rb', line 4393 class DescribeDBParameterGroupsMessage < Struct.new( :db_parameter_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeDBParameterGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
4393 4394 4395 4396 4397 4398 4399 4400 |
# File 'lib/aws-sdk-neptune/types.rb', line 4393 class DescribeDBParameterGroupsMessage < Struct.new( :db_parameter_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
4393 4394 4395 4396 4397 4398 4399 4400 |
# File 'lib/aws-sdk-neptune/types.rb', line 4393 class DescribeDBParameterGroupsMessage < Struct.new( :db_parameter_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |