Class: Aws::Neptune::Types::DescribeDBParametersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::DescribeDBParametersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_parameter_group_name ⇒ String
The name of a specific DB parameter group to return details for.
-
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBParametersrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#source ⇒ String
The parameter types to return.
Instance Attribute Details
#db_parameter_group_name ⇒ String
The name of a specific DB parameter group to return details for.
Constraints:
-
If supplied, must match the name of an existing DBParameterGroup.
^
4444 4445 4446 4447 4448 4449 4450 4451 4452 |
# File 'lib/aws-sdk-neptune/types.rb', line 4444 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
4444 4445 4446 4447 4448 4449 4450 4451 4452 |
# File 'lib/aws-sdk-neptune/types.rb', line 4444 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeDBParameters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
4444 4445 4446 4447 4448 4449 4450 4451 4452 |
# File 'lib/aws-sdk-neptune/types.rb', line 4444 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
4444 4445 4446 4447 4448 4449 4450 4451 4452 |
# File 'lib/aws-sdk-neptune/types.rb', line 4444 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The parameter types to return.
Default: All parameter types returned
Valid Values: ‘user | system | engine-default`
4444 4445 4446 4447 4448 4449 4450 4451 4452 |
# File 'lib/aws-sdk-neptune/types.rb', line 4444 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |