Class: Aws::Neptune::Types::DescribeDBSubnetGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::DescribeDBSubnetGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_subnet_group_name ⇒ String
The name of the DB subnet group to return details for.
-
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous DescribeDBSubnetGroups request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_subnet_group_name ⇒ String
The name of the DB subnet group to return details for.
4471 4472 4473 4474 4475 4476 4477 4478 |
# File 'lib/aws-sdk-neptune/types.rb', line 4471 class DescribeDBSubnetGroupsMessage < Struct.new( :db_subnet_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
4471 4472 4473 4474 4475 4476 4477 4478 |
# File 'lib/aws-sdk-neptune/types.rb', line 4471 class DescribeDBSubnetGroupsMessage < Struct.new( :db_subnet_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeDBSubnetGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
4471 4472 4473 4474 4475 4476 4477 4478 |
# File 'lib/aws-sdk-neptune/types.rb', line 4471 class DescribeDBSubnetGroupsMessage < Struct.new( :db_subnet_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
4471 4472 4473 4474 4475 4476 4477 4478 |
# File 'lib/aws-sdk-neptune/types.rb', line 4471 class DescribeDBSubnetGroupsMessage < Struct.new( :db_subnet_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |