Class: Aws::Neptune::Types::DescribeEngineDefaultClusterParametersMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_parameter_group_familyString

The name of the DB cluster parameter group family to return engine parameter information for.



4520
4521
4522
4523
4524
4525
4526
4527
# File 'lib/aws-sdk-neptune/types.rb', line 4520

class DescribeEngineDefaultClusterParametersMessage < Struct.new(
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter is not currently supported.



4520
4521
4522
4523
4524
4525
4526
4527
# File 'lib/aws-sdk-neptune/types.rb', line 4520

class DescribeEngineDefaultClusterParametersMessage < Struct.new(
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeEngineDefaultClusterParameters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



4520
4521
4522
4523
4524
4525
4526
4527
# File 'lib/aws-sdk-neptune/types.rb', line 4520

class DescribeEngineDefaultClusterParametersMessage < Struct.new(
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.



4520
4521
4522
4523
4524
4525
4526
4527
# File 'lib/aws-sdk-neptune/types.rb', line 4520

class DescribeEngineDefaultClusterParametersMessage < Struct.new(
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end