Class: Aws::Neptune::Types::DescribeEngineDefaultParametersMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_parameter_group_familyString

The name of the DB parameter group family.



4570
4571
4572
4573
4574
4575
4576
4577
# File 'lib/aws-sdk-neptune/types.rb', line 4570

class DescribeEngineDefaultParametersMessage < Struct.new(
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Not currently supported.



4570
4571
4572
4573
4574
4575
4576
4577
# File 'lib/aws-sdk-neptune/types.rb', line 4570

class DescribeEngineDefaultParametersMessage < Struct.new(
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeEngineDefaultParameters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



4570
4571
4572
4573
4574
4575
4576
4577
# File 'lib/aws-sdk-neptune/types.rb', line 4570

class DescribeEngineDefaultParametersMessage < Struct.new(
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.



4570
4571
4572
4573
4574
4575
4576
4577
# File 'lib/aws-sdk-neptune/types.rb', line 4570

class DescribeEngineDefaultParametersMessage < Struct.new(
  :db_parameter_group_family,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end