Class: Aws::Neptune::Types::DescribeGlobalClustersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::DescribeGlobalClustersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#global_cluster_identifier ⇒ String
The user-supplied DB cluster identifier.
-
#marker ⇒ String
(Optional) A pagination token returned by a previous call to
DescribeGlobalClusters. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#global_cluster_identifier ⇒ String
The user-supplied DB cluster identifier. If this parameter is specified, only information about the specified DB cluster is returned. This parameter is not case-sensitive.
Constraints: If supplied, must match an existing DB cluster identifier.
4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/aws-sdk-neptune/types.rb', line 4780 class DescribeGlobalClustersMessage < Struct.new( :global_cluster_identifier, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
(Optional) A pagination token returned by a previous call to DescribeGlobalClusters. If this parameter is specified, the response will only include records beyond the marker, up to the number specified by MaxRecords.
4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/aws-sdk-neptune/types.rb', line 4780 class DescribeGlobalClustersMessage < Struct.new( :global_cluster_identifier, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination marker token is included in the response that you can use to retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/aws-sdk-neptune/types.rb', line 4780 class DescribeGlobalClustersMessage < Struct.new( :global_cluster_identifier, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |