Class: Aws::Neptune::Types::DescribeOrderableDBInstanceOptionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_instance_classString

The DB instance class filter value. Specify this parameter to show only the available offerings matching the specified DB instance class.



4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-neptune/types.rb', line 4837

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The name of the engine to retrieve DB instance options for.



4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-neptune/types.rb', line 4837

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The engine version filter value. Specify this parameter to show only the available offerings matching the specified engine version.



4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-neptune/types.rb', line 4837

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter is not currently supported.



4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-neptune/types.rb', line 4837

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#license_modelString

The license model filter value. Specify this parameter to show only the available offerings matching the specified license model.



4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-neptune/types.rb', line 4837

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .



4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-neptune/types.rb', line 4837

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.



4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-neptune/types.rb', line 4837

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#vpcBoolean

The VPC filter value. Specify this parameter to show only the available VPC or non-VPC offerings.



4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/aws-sdk-neptune/types.rb', line 4837

class DescribeOrderableDBInstanceOptionsMessage < Struct.new(
  :engine,
  :engine_version,
  :db_instance_class,
  :license_model,
  :vpc,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end