Class: Aws::Neptune::Types::EngineDefaults
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::EngineDefaults
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Contains the result of a successful invocation of the DescribeEngineDefaultParameters action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_parameter_group_family ⇒ String
Specifies the name of the DB parameter group family that the engine default parameters apply to.
-
#marker ⇒ String
An optional pagination token provided by a previous EngineDefaults request.
-
#parameters ⇒ Array<Types::Parameter>
Contains a list of engine default parameters.
Instance Attribute Details
#db_parameter_group_family ⇒ String
Specifies the name of the DB parameter group family that the engine default parameters apply to.
5032 5033 5034 5035 5036 5037 5038 |
# File 'lib/aws-sdk-neptune/types.rb', line 5032 class EngineDefaults < Struct.new( :db_parameter_group_family, :marker, :parameters) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous EngineDefaults request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
5032 5033 5034 5035 5036 5037 5038 |
# File 'lib/aws-sdk-neptune/types.rb', line 5032 class EngineDefaults < Struct.new( :db_parameter_group_family, :marker, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::Parameter>
Contains a list of engine default parameters.
5032 5033 5034 5035 5036 5037 5038 |
# File 'lib/aws-sdk-neptune/types.rb', line 5032 class EngineDefaults < Struct.new( :db_parameter_group_family, :marker, :parameters) SENSITIVE = [] include Aws::Structure end |