Class: Aws::Neptune::Types::EventsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::EventsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::Event>
A list of Event instances.
-
#marker ⇒ String
An optional pagination token provided by a previous Events request.
Instance Attribute Details
#events ⇒ Array<Types::Event>
A list of Event instances.
5222 5223 5224 5225 5226 5227 |
# File 'lib/aws-sdk-neptune/types.rb', line 5222 class EventsMessage < Struct.new( :marker, :events) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous Events request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .
5222 5223 5224 5225 5226 5227 |
# File 'lib/aws-sdk-neptune/types.rb', line 5222 class EventsMessage < Struct.new( :marker, :events) SENSITIVE = [] include Aws::Structure end |