Class: Aws::Neptune::Types::GlobalClustersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::GlobalClustersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#global_clusters ⇒ Array<Types::GlobalCluster>
The list of global clusters and instances returned by this request.
-
#marker ⇒ String
A pagination token.
Instance Attribute Details
#global_clusters ⇒ Array<Types::GlobalCluster>
The list of global clusters and instances returned by this request.
5553 5554 5555 5556 5557 5558 |
# File 'lib/aws-sdk-neptune/types.rb', line 5553 class GlobalClustersMessage < Struct.new( :marker, :global_clusters) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A pagination token. If this parameter is returned in the response, more records are available, which can be retrieved by one or more additional calls to DescribeGlobalClusters.
5553 5554 5555 5556 5557 5558 |
# File 'lib/aws-sdk-neptune/types.rb', line 5553 class GlobalClustersMessage < Struct.new( :marker, :global_clusters) SENSITIVE = [] include Aws::Structure end |