Class: Aws::Neptune::Types::ModifyDBParameterGroupMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_parameter_group_nameString

The name of the DB parameter group.

Constraints:

  • If supplied, must match the name of an existing DBParameterGroup.

^

Returns:

  • (String)


6604
6605
6606
6607
6608
6609
# File 'lib/aws-sdk-neptune/types.rb', line 6604

class ModifyDBParameterGroupMessage < Struct.new(
  :db_parameter_group_name,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersArray<Types::Parameter>

An array of parameter names, values, and the apply method for the parameter update. At least one parameter name, value, and apply method must be supplied; subsequent arguments are optional. A maximum of 20 parameters can be modified in a single request.

Valid Values (for the application method): ‘immediate | pending-reboot`

<note markdown=“1”> You can use the immediate value with dynamic parameters only. You can use the pending-reboot value for both dynamic and static parameters, and changes are applied when you reboot the DB instance without failover.

</note>

Returns:



6604
6605
6606
6607
6608
6609
# File 'lib/aws-sdk-neptune/types.rb', line 6604

class ModifyDBParameterGroupMessage < Struct.new(
  :db_parameter_group_name,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end