Class: Aws::Neptune::Types::OrderableDBInstanceOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::OrderableDBInstanceOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Contains a list of available options for a DB instance.
This data type is used as a response element in the DescribeOrderableDBInstanceOptions action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<Types::AvailabilityZone>
A list of Availability Zones for a DB instance.
-
#db_instance_class ⇒ String
The DB instance class for a DB instance.
-
#engine ⇒ String
The engine type of a DB instance.
-
#engine_version ⇒ String
The engine version of a DB instance.
-
#license_model ⇒ String
The license model for a DB instance.
-
#max_iops_per_db_instance ⇒ Integer
Maximum total provisioned IOPS for a DB instance.
-
#max_iops_per_gib ⇒ Float
Maximum provisioned IOPS per GiB for a DB instance.
-
#max_storage_size ⇒ Integer
Maximum storage size for a DB instance.
-
#min_iops_per_db_instance ⇒ Integer
Minimum total provisioned IOPS for a DB instance.
-
#min_iops_per_gib ⇒ Float
Minimum provisioned IOPS per GiB for a DB instance.
-
#min_storage_size ⇒ Integer
Minimum storage size for a DB instance.
-
#multi_az_capable ⇒ Boolean
Indicates whether a DB instance is Multi-AZ capable.
-
#read_replica_capable ⇒ Boolean
Indicates whether a DB instance can have a Read Replica.
-
#storage_type ⇒ String
Not applicable.
-
#supports_enhanced_monitoring ⇒ Boolean
Indicates whether a DB instance supports Enhanced Monitoring at intervals from 1 to 60 seconds.
-
#supports_global_databases ⇒ Boolean
A value that indicates whether you can use Neptune global databases with a specific combination of other DB engine attributes.
-
#supports_iam_database_authentication ⇒ Boolean
Indicates whether a DB instance supports IAM database authentication.
-
#supports_iops ⇒ Boolean
Indicates whether a DB instance supports provisioned IOPS.
-
#supports_performance_insights ⇒ Boolean
*(Not supported by Neptune)*.
-
#supports_storage_encryption ⇒ Boolean
Indicates whether a DB instance supports encrypted storage.
-
#vpc ⇒ Boolean
Indicates whether a DB instance is in a VPC.
Instance Attribute Details
#availability_zones ⇒ Array<Types::AvailabilityZone>
A list of Availability Zones for a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#db_instance_class ⇒ String
The DB instance class for a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The engine type of a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The engine version of a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#license_model ⇒ String
The license model for a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#max_iops_per_db_instance ⇒ Integer
Maximum total provisioned IOPS for a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#max_iops_per_gib ⇒ Float
Maximum provisioned IOPS per GiB for a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#max_storage_size ⇒ Integer
Maximum storage size for a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#min_iops_per_db_instance ⇒ Integer
Minimum total provisioned IOPS for a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#min_iops_per_gib ⇒ Float
Minimum provisioned IOPS per GiB for a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#min_storage_size ⇒ Integer
Minimum storage size for a DB instance.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#multi_az_capable ⇒ Boolean
Indicates whether a DB instance is Multi-AZ capable.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#read_replica_capable ⇒ Boolean
Indicates whether a DB instance can have a Read Replica.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
Not applicable. In Neptune the storage type is managed at the DB Cluster level.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supports_enhanced_monitoring ⇒ Boolean
Indicates whether a DB instance supports Enhanced Monitoring at intervals from 1 to 60 seconds.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supports_global_databases ⇒ Boolean
A value that indicates whether you can use Neptune global databases with a specific combination of other DB engine attributes.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supports_iam_database_authentication ⇒ Boolean
Indicates whether a DB instance supports IAM database authentication.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supports_iops ⇒ Boolean
Indicates whether a DB instance supports provisioned IOPS.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supports_performance_insights ⇒ Boolean
*(Not supported by Neptune)*
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#supports_storage_encryption ⇒ Boolean
Indicates whether a DB instance supports encrypted storage.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |
#vpc ⇒ Boolean
Indicates whether a DB instance is in a VPC.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 |
# File 'lib/aws-sdk-neptune/types.rb', line 6910 class OrderableDBInstanceOption < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zones, :multi_az_capable, :read_replica_capable, :vpc, :supports_storage_encryption, :storage_type, :supports_iops, :supports_enhanced_monitoring, :supports_iam_database_authentication, :supports_performance_insights, :min_storage_size, :max_storage_size, :min_iops_per_db_instance, :max_iops_per_db_instance, :min_iops_per_gib, :max_iops_per_gib, :supports_global_databases) SENSITIVE = [] include Aws::Structure end |