Class: Aws::Neptune::Types::Parameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::Parameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Specifies a parameter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ String
Specifies the valid range of values for the parameter.
-
#apply_method ⇒ String
Indicates when to apply parameter updates.
-
#apply_type ⇒ String
Specifies the engine specific parameters type.
-
#data_type ⇒ String
Specifies the valid data type for the parameter.
-
#description ⇒ String
Provides a description of the parameter.
-
#is_modifiable ⇒ Boolean
Indicates whether (‘true`) or not (`false`) the parameter can be modified.
-
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
-
#parameter_name ⇒ String
Specifies the name of the parameter.
-
#parameter_value ⇒ String
Specifies the value of the parameter.
-
#source ⇒ String
Indicates the source of the parameter value.
Instance Attribute Details
#allowed_values ⇒ String
Specifies the valid range of values for the parameter.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#apply_method ⇒ String
Indicates when to apply parameter updates.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#apply_type ⇒ String
Specifies the engine specific parameters type.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ String
Specifies the valid data type for the parameter.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Provides a description of the parameter.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#is_modifiable ⇒ Boolean
Indicates whether (‘true`) or not (`false`) the parameter can be modified. Some parameters have security or operational implications that prevent them from being changed.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#parameter_name ⇒ String
Specifies the name of the parameter.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#parameter_value ⇒ String
Specifies the value of the parameter.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
Indicates the source of the parameter value.
7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-neptune/types.rb', line 7079 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method) SENSITIVE = [] include Aws::Structure end |