Class: Aws::Neptune::Types::PendingMaintenanceActionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

An optional pagination token provided by a previous DescribePendingMaintenanceActions request. If this parameter is specified, the response includes only records beyond the marker, up to a number of records specified by MaxRecords.

Returns:

  • (String)


7116
7117
7118
7119
7120
7121
# File 'lib/aws-sdk-neptune/types.rb', line 7116

class PendingMaintenanceActionsMessage < Struct.new(
  :pending_maintenance_actions,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#pending_maintenance_actionsArray<Types::ResourcePendingMaintenanceActions>

A list of the pending maintenance actions for the resource.



7116
7117
7118
7119
7120
7121
# File 'lib/aws-sdk-neptune/types.rb', line 7116

class PendingMaintenanceActionsMessage < Struct.new(
  :pending_maintenance_actions,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end