Class: Aws::Neptune::Types::PendingModifiedValues

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptune/types.rb

Overview

This data type is used as a response element in the ModifyDBInstance action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

Contains the new AllocatedStorage size for the DB instance that will be applied or is currently being applied.

Returns:

  • (Integer)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#backup_retention_periodInteger

Specifies the pending number of days for which automated backups are retained.

Returns:

  • (Integer)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#ca_certificate_identifierString

Specifies the identifier of the CA certificate for the DB instance.

Returns:

  • (String)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_classString

Contains the new DBInstanceClass for the DB instance that will be applied or is currently being applied.

Returns:

  • (String)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_identifierString

Contains the new DBInstanceIdentifier for the DB instance that will be applied or is currently being applied.

Returns:

  • (String)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#db_subnet_group_nameString

The new DB subnet group for the DB instance.

Returns:

  • (String)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

Indicates the database engine version.

Returns:

  • (String)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#iopsInteger

Specifies the new Provisioned IOPS value for the DB instance that will be applied or is currently being applied.

Returns:

  • (Integer)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#license_modelString

Not supported by Neptune.

Returns:

  • (String)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#master_user_passwordString

Not supported by Neptune.

Returns:

  • (String)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#multi_azBoolean

Indicates that the Single-AZ DB instance is to change to a Multi-AZ deployment.

Returns:

  • (Boolean)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#pending_cloudwatch_logs_exportsTypes::PendingCloudwatchLogsExports

This PendingCloudwatchLogsExports structure specifies pending changes to which CloudWatch logs are enabled and which are disabled.



7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

Specifies the pending port for the DB instance.

Returns:

  • (Integer)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

Not applicable. In Neptune the storage type is managed at the DB Cluster level.

Returns:

  • (String)


7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-neptune/types.rb', line 7192

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports)
  SENSITIVE = []
  include Aws::Structure
end