Class: Aws::Neptune::Types::RebootDBInstanceMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::RebootDBInstanceMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_instance_identifier ⇒ String
The DB instance identifier.
-
#force_failover ⇒ Boolean
When
true, the reboot is conducted through a MultiAZ failover.
Instance Attribute Details
#db_instance_identifier ⇒ String
The DB instance identifier. This parameter is stored as a lowercase string.
Constraints:
-
Must match the identifier of an existing DBInstance.
^
7292 7293 7294 7295 7296 7297 |
# File 'lib/aws-sdk-neptune/types.rb', line 7292 class RebootDBInstanceMessage < Struct.new( :db_instance_identifier, :force_failover) SENSITIVE = [] include Aws::Structure end |
#force_failover ⇒ Boolean
When true, the reboot is conducted through a MultiAZ failover.
Constraint: You can’t specify true if the instance is not configured for MultiAZ.
7292 7293 7294 7295 7296 7297 |
# File 'lib/aws-sdk-neptune/types.rb', line 7292 class RebootDBInstanceMessage < Struct.new( :db_instance_identifier, :force_failover) SENSITIVE = [] include Aws::Structure end |