Class: Aws::Neptune::Types::RestoreDBClusterFromSnapshotMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::RestoreDBClusterFromSnapshotMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<String>
Provides the list of EC2 Availability Zones that instances in the restored DB cluster can be created in.
-
#copy_tags_to_snapshot ⇒ Boolean
*If set to
true, tags are copied to any snapshot of the restored DB cluster that is created.*. -
#database_name ⇒ String
Not supported.
-
#db_cluster_identifier ⇒ String
The name of the DB cluster to create from the DB snapshot or DB cluster snapshot.
-
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group to associate with the new DB cluster.
-
#db_subnet_group_name ⇒ String
The name of the DB subnet group to use for the new DB cluster.
-
#deletion_protection ⇒ Boolean
A value that indicates whether the DB cluster has deletion protection enabled.
-
#enable_cloudwatch_logs_exports ⇒ Array<String>
The list of logs that the restored DB cluster is to export to Amazon CloudWatch Logs.
-
#enable_iam_database_authentication ⇒ Boolean
True to enable mapping of Amazon Identity and Access Management (IAM) accounts to database accounts, and otherwise false.
-
#engine ⇒ String
The database engine to use for the new DB cluster.
-
#engine_version ⇒ String
The version of the database engine to use for the new DB cluster.
-
#kms_key_id ⇒ String
The Amazon KMS key identifier to use when restoring an encrypted DB cluster from a DB snapshot or DB cluster snapshot.
-
#option_group_name ⇒ String
*(Not supported by Neptune)*.
-
#port ⇒ Integer
The port number on which the new DB cluster accepts connections.
-
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfiguration
Contains the scaling configuration of a Neptune Serverless DB cluster.
-
#snapshot_identifier ⇒ String
The identifier for the DB snapshot or DB cluster snapshot to restore from.
-
#storage_type ⇒ String
Specifies the storage type to be associated with the DB cluster.
-
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the restored DB cluster.
-
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security groups that the new DB cluster will belong to.
Instance Attribute Details
#availability_zones ⇒ Array<String>
Provides the list of EC2 Availability Zones that instances in the restored DB cluster can be created in.
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#copy_tags_to_snapshot ⇒ Boolean
*If set to true, tags are copied to any snapshot of the restored DB cluster that is created.*
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
Not supported.
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
The name of the DB cluster to create from the DB snapshot or DB cluster snapshot. This parameter isn’t case-sensitive.
Constraints:
-
Must contain from 1 to 63 letters, numbers, or hyphens
-
First character must be a letter
-
Cannot end with a hyphen or contain two consecutive hyphens
Example: my-snapshot-id
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group to associate with the new DB cluster.
Constraints:
-
If supplied, must match the name of an existing DBClusterParameterGroup.
^
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#db_subnet_group_name ⇒ String
The name of the DB subnet group to use for the new DB cluster.
Constraints: If supplied, must match the name of an existing DBSubnetGroup.
Example: mySubnetgroup
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ Boolean
A value that indicates whether the DB cluster has deletion protection enabled. The database can’t be deleted when deletion protection is enabled. By default, deletion protection is disabled.
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#enable_cloudwatch_logs_exports ⇒ Array<String>
The list of logs that the restored DB cluster is to export to Amazon CloudWatch Logs.
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#enable_iam_database_authentication ⇒ Boolean
True to enable mapping of Amazon Identity and Access Management (IAM) accounts to database accounts, and otherwise false.
Default: false
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The database engine to use for the new DB cluster.
Default: The same as source
Constraint: Must be compatible with the engine of the source
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version of the database engine to use for the new DB cluster.
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon KMS key identifier to use when restoring an encrypted DB cluster from a DB snapshot or DB cluster snapshot.
The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are restoring a DB cluster with the same Amazon account that owns the KMS encryption key used to encrypt the new DB cluster, then you can use the KMS key alias instead of the ARN for the KMS encryption key.
If you do not specify a value for the KmsKeyId parameter, then the following will occur:
-
If the DB snapshot or DB cluster snapshot in
SnapshotIdentifieris encrypted, then the restored DB cluster is encrypted using the KMS key that was used to encrypt the DB snapshot or DB cluster snapshot. -
If the DB snapshot or DB cluster snapshot in
SnapshotIdentifieris not encrypted, then the restored DB cluster is not encrypted.
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#option_group_name ⇒ String
*(Not supported by Neptune)*
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which the new DB cluster accepts connections.
Constraints: Value must be 1150-65535
Default: The same port as the original DB cluster.
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfiguration
Contains the scaling configuration of a Neptune Serverless DB cluster.
For more information, see [Using Amazon Neptune Serverless] in the *Amazon Neptune User Guide*.
[1]: docs.aws.amazon.com/neptune/latest/userguide/neptune-serverless-using.html
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#snapshot_identifier ⇒ String
The identifier for the DB snapshot or DB cluster snapshot to restore from.
You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot.
Constraints:
-
Must match the identifier of an existing Snapshot.
^
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
Specifies the storage type to be associated with the DB cluster.
Valid values: standard, iopt1
Default: standard
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to be assigned to the restored DB cluster.
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security groups that the new DB cluster will belong to.
7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 |
# File 'lib/aws-sdk-neptune/types.rb', line 7683 class RestoreDBClusterFromSnapshotMessage < Struct.new( :availability_zones, :db_cluster_identifier, :snapshot_identifier, :engine, :engine_version, :port, :db_subnet_group_name, :database_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :copy_tags_to_snapshot, :serverless_v2_scaling_configuration, :storage_type) SENSITIVE = [] include Aws::Structure end |