Class: Aws::Neptune::Types::RestoreDBClusterToPointInTimeMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::RestoreDBClusterToPointInTimeMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_cluster_identifier ⇒ String
The name of the new DB cluster to be created.
-
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group to associate with the new DB cluster.
-
#db_subnet_group_name ⇒ String
The DB subnet group name to use for the new DB cluster.
-
#deletion_protection ⇒ Boolean
A value that indicates whether the DB cluster has deletion protection enabled.
-
#enable_cloudwatch_logs_exports ⇒ Array<String>
The list of logs that the restored DB cluster is to export to CloudWatch Logs.
-
#enable_iam_database_authentication ⇒ Boolean
True to enable mapping of Amazon Identity and Access Management (IAM) accounts to database accounts, and otherwise false.
-
#kms_key_id ⇒ String
The Amazon KMS key identifier to use when restoring an encrypted DB cluster from an encrypted DB cluster.
-
#network_type ⇒ String
The network type of the DB cluster.
-
#option_group_name ⇒ String
*(Not supported by Neptune)*.
-
#port ⇒ Integer
The port number on which the new DB cluster accepts connections.
-
#restore_to_time ⇒ Time
The date and time to restore the DB cluster to.
-
#restore_type ⇒ String
The type of restore to be performed.
-
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfiguration
Contains the scaling configuration of a Neptune Serverless DB cluster.
-
#source_db_cluster_identifier ⇒ String
The identifier of the source DB cluster from which to restore.
-
#storage_type ⇒ String
Specifies the storage type to be associated with the DB cluster.
-
#tags ⇒ Array<Types::Tag>
The tags to be applied to the restored DB cluster.
-
#use_latest_restorable_time ⇒ Boolean
A value that is set to ‘true` to restore the DB cluster to the latest restorable backup time, and `false` otherwise.
-
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security groups that the new DB cluster belongs to.
Instance Attribute Details
#db_cluster_identifier ⇒ String
The name of the new DB cluster to be created.
Constraints:
-
Must contain from 1 to 63 letters, numbers, or hyphens
-
First character must be a letter
-
Cannot end with a hyphen or contain two consecutive hyphens
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group to associate with the new DB cluster.
Constraints:
-
If supplied, must match the name of an existing DBClusterParameterGroup.
^
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#db_subnet_group_name ⇒ String
The DB subnet group name to use for the new DB cluster.
Constraints: If supplied, must match the name of an existing DBSubnetGroup.
Example: ‘mySubnetgroup`
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ Boolean
A value that indicates whether the DB cluster has deletion protection enabled. The database can’t be deleted when deletion protection is enabled. By default, deletion protection is disabled.
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#enable_cloudwatch_logs_exports ⇒ Array<String>
The list of logs that the restored DB cluster is to export to CloudWatch Logs.
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#enable_iam_database_authentication ⇒ Boolean
True to enable mapping of Amazon Identity and Access Management (IAM) accounts to database accounts, and otherwise false.
Default: ‘false`
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon KMS key identifier to use when restoring an encrypted DB cluster from an encrypted DB cluster.
The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are restoring a DB cluster with the same Amazon account that owns the KMS encryption key used to encrypt the new DB cluster, then you can use the KMS key alias instead of the ARN for the KMS encryption key.
You can restore to a new DB cluster and encrypt the new DB cluster with a KMS key that is different than the KMS key used to encrypt the source DB cluster. The new DB cluster is encrypted with the KMS key identified by the ‘KmsKeyId` parameter.
If you do not specify a value for the ‘KmsKeyId` parameter, then the following will occur:
-
If the DB cluster is encrypted, then the restored DB cluster is encrypted using the KMS key that was used to encrypt the source DB cluster.
-
If the DB cluster is not encrypted, then the restored DB cluster is not encrypted.
If ‘DBClusterIdentifier` refers to a DB cluster that is not encrypted, then the restore request is rejected.
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
The network type of the DB cluster.
Valid Values:
-
IPV4– ( *the default* ) The DB cluster uses only IPv4 addresses for communication. -
DUAL– The DB cluster uses both IPv4 and IPv6 addresses for communication. The DB subnet group associated with the cluster must support IPv6.
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#option_group_name ⇒ String
*(Not supported by Neptune)*
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which the new DB cluster accepts connections.
Constraints: Value must be ‘1150-65535`
Default: The same port as the original DB cluster.
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#restore_to_time ⇒ Time
The date and time to restore the DB cluster to.
Valid Values: Value must be a time in Universal Coordinated Time (UTC) format
Constraints:
-
Must be before the latest restorable time for the DB instance
-
Must be specified if ‘UseLatestRestorableTime` parameter is not provided
-
Cannot be specified if ‘UseLatestRestorableTime` parameter is true
-
Cannot be specified if ‘RestoreType` parameter is `copy-on-write`
Example: ‘2015-03-07T23:45:00Z`
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#restore_type ⇒ String
The type of restore to be performed. You can specify one of the following values:
-
‘full-copy` - The new DB cluster is restored as a full copy of the source DB cluster.
-
‘copy-on-write` - The new DB cluster is restored as a clone of the source DB cluster.
If you don’t specify a ‘RestoreType` value, then the new DB cluster is restored as a full copy of the source DB cluster.
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfiguration
Contains the scaling configuration of a Neptune Serverless DB cluster.
For more information, see [Using Amazon Neptune Serverless] in the *Amazon Neptune User Guide*.
[1]: docs.aws.amazon.com/neptune/latest/userguide/neptune-serverless-using.html
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#source_db_cluster_identifier ⇒ String
The identifier of the source DB cluster from which to restore.
Constraints:
-
Must match the identifier of an existing DBCluster.
^
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
Specifies the storage type to be associated with the DB cluster.
Valid values: ‘standard`, `iopt1`
Default: ‘standard`
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to be applied to the restored DB cluster.
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#use_latest_restorable_time ⇒ Boolean
A value that is set to ‘true` to restore the DB cluster to the latest restorable backup time, and `false` otherwise.
Default: ‘false`
Constraints: Cannot be specified if ‘RestoreToTime` parameter is provided.
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |
#vpc_security_group_ids ⇒ Array<String>
A list of VPC security groups that the new DB cluster belongs to.
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/aws-sdk-neptune/types.rb', line 8001 class RestoreDBClusterToPointInTimeMessage < Struct.new( :db_cluster_identifier, :restore_type, :source_db_cluster_identifier, :restore_to_time, :use_latest_restorable_time, :port, :db_subnet_group_name, :option_group_name, :vpc_security_group_ids, :tags, :kms_key_id, :enable_iam_database_authentication, :enable_cloudwatch_logs_exports, :db_cluster_parameter_group_name, :deletion_protection, :serverless_v2_scaling_configuration, :storage_type, :network_type) SENSITIVE = [] include Aws::Structure end |