Class: Aws::Neptune::Waiters::DBInstanceAvailable
- Inherits:
-
Object
- Object
- Aws::Neptune::Waiters::DBInstanceAvailable
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-neptune/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ DBInstanceAvailable
constructor
A new instance of DBInstanceAvailable.
-
#wait(params = {}) ⇒ Types::DBInstanceMessage
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ DBInstanceAvailable
Returns a new instance of DBInstanceAvailable.
85 86 |
# File 'lib/aws-sdk-neptune/waiters.rb', line 85
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
141 142 143 |
# File 'lib/aws-sdk-neptune/waiters.rb', line 141 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DBInstanceMessage
Returns a response object which responds to the following methods:
- #marker => String
- #db_instances => Array<Types::DBInstance>
136 |
# File 'lib/aws-sdk-neptune/waiters.rb', line 136
def wait: (
|