Class: Aws::Neptune::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Neptune::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-neptune/client.rb
Overview
An API client for Neptune. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Neptune::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_role_to_db_cluster(params = {}) ⇒ Struct
Associates an Identity and Access Management (IAM) role with an Neptune DB cluster.
-
#add_source_identifier_to_subscription(params = {}) ⇒ Types::AddSourceIdentifierToSubscriptionResult
Adds a source identifier to an existing event notification subscription.
-
#add_tags_to_resource(params = {}) ⇒ Struct
Adds metadata tags to an Amazon Neptune resource.
-
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionResult
Applies a pending maintenance action to a resource (for example, to a DB instance).
-
#copy_db_cluster_parameter_group(params = {}) ⇒ Types::CopyDBClusterParameterGroupResult
Copies the specified DB cluster parameter group.
-
#copy_db_cluster_snapshot(params = {}) ⇒ Types::CopyDBClusterSnapshotResult
Copies a snapshot of a DB cluster.
-
#copy_db_parameter_group(params = {}) ⇒ Types::CopyDBParameterGroupResult
Copies the specified DB parameter group.
-
#create_db_cluster(params = {}) ⇒ Types::CreateDBClusterResult
Creates a new Amazon Neptune DB cluster.
-
#create_db_cluster_endpoint(params = {}) ⇒ Types::CreateDBClusterEndpointOutput
Creates a new custom endpoint and associates it with an Amazon Neptune DB cluster.
-
#create_db_cluster_parameter_group(params = {}) ⇒ Types::CreateDBClusterParameterGroupResult
Creates a new DB cluster parameter group.
-
#create_db_cluster_snapshot(params = {}) ⇒ Types::CreateDBClusterSnapshotResult
Creates a snapshot of a DB cluster.
-
#create_db_instance(params = {}) ⇒ Types::CreateDBInstanceResult
Creates a new DB instance.
-
#create_db_parameter_group(params = {}) ⇒ Types::CreateDBParameterGroupResult
Creates a new DB parameter group.
-
#create_db_subnet_group(params = {}) ⇒ Types::CreateDBSubnetGroupResult
Creates a new DB subnet group.
-
#create_event_subscription(params = {}) ⇒ Types::CreateEventSubscriptionResult
Creates an event notification subscription.
-
#create_global_cluster(params = {}) ⇒ Types::CreateGlobalClusterResult
Creates a Neptune global database spread across multiple Amazon Regions.
-
#delete_db_cluster(params = {}) ⇒ Types::DeleteDBClusterResult
The DeleteDBCluster action deletes a previously provisioned DB cluster.
-
#delete_db_cluster_endpoint(params = {}) ⇒ Types::DeleteDBClusterEndpointOutput
Deletes a custom endpoint and removes it from an Amazon Neptune DB cluster.
-
#delete_db_cluster_parameter_group(params = {}) ⇒ Struct
Deletes a specified DB cluster parameter group.
-
#delete_db_cluster_snapshot(params = {}) ⇒ Types::DeleteDBClusterSnapshotResult
Deletes a DB cluster snapshot.
-
#delete_db_instance(params = {}) ⇒ Types::DeleteDBInstanceResult
The DeleteDBInstance action deletes a previously provisioned DB instance.
-
#delete_db_parameter_group(params = {}) ⇒ Struct
Deletes a specified DBParameterGroup.
-
#delete_db_subnet_group(params = {}) ⇒ Struct
Deletes a DB subnet group.
-
#delete_event_subscription(params = {}) ⇒ Types::DeleteEventSubscriptionResult
Deletes an event notification subscription.
-
#delete_global_cluster(params = {}) ⇒ Types::DeleteGlobalClusterResult
Deletes a global database.
-
#describe_db_cluster_endpoints(params = {}) ⇒ Types::DBClusterEndpointMessage
Returns information about endpoints for an Amazon Neptune DB cluster.
-
#describe_db_cluster_parameter_groups(params = {}) ⇒ Types::DBClusterParameterGroupsMessage
Returns a list of ‘DBClusterParameterGroup` descriptions.
-
#describe_db_cluster_parameters(params = {}) ⇒ Types::DBClusterParameterGroupDetails
Returns the detailed parameter list for a particular DB cluster parameter group.
-
#describe_db_cluster_snapshot_attributes(params = {}) ⇒ Types::DescribeDBClusterSnapshotAttributesResult
Returns a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot.
-
#describe_db_cluster_snapshots(params = {}) ⇒ Types::DBClusterSnapshotMessage
Returns information about DB cluster snapshots.
-
#describe_db_clusters(params = {}) ⇒ Types::DBClusterMessage
Returns information about provisioned DB clusters, and supports pagination.
-
#describe_db_engine_versions(params = {}) ⇒ Types::DBEngineVersionMessage
Returns a list of the available DB engines.
-
#describe_db_instances(params = {}) ⇒ Types::DBInstanceMessage
Returns information about provisioned instances, and supports pagination.
-
#describe_db_parameter_groups(params = {}) ⇒ Types::DBParameterGroupsMessage
Returns a list of ‘DBParameterGroup` descriptions.
-
#describe_db_parameters(params = {}) ⇒ Types::DBParameterGroupDetails
Returns the detailed parameter list for a particular DB parameter group.
-
#describe_db_subnet_groups(params = {}) ⇒ Types::DBSubnetGroupMessage
Returns a list of DBSubnetGroup descriptions.
-
#describe_engine_default_cluster_parameters(params = {}) ⇒ Types::DescribeEngineDefaultClusterParametersResult
Returns the default engine and system parameter information for the cluster database engine.
-
#describe_engine_default_parameters(params = {}) ⇒ Types::DescribeEngineDefaultParametersResult
Returns the default engine and system parameter information for the specified database engine.
-
#describe_event_categories(params = {}) ⇒ Types::EventCategoriesMessage
Displays a list of categories for all event source types, or, if specified, for a specified source type.
-
#describe_event_subscriptions(params = {}) ⇒ Types::EventSubscriptionsMessage
Lists all the subscription descriptions for a customer account.
-
#describe_events(params = {}) ⇒ Types::EventsMessage
Returns events related to DB instances, DB security groups, DB snapshots, and DB parameter groups for the past 14 days.
-
#describe_global_clusters(params = {}) ⇒ Types::GlobalClustersMessage
Returns information about Neptune global database clusters.
-
#describe_orderable_db_instance_options(params = {}) ⇒ Types::OrderableDBInstanceOptionsMessage
Returns a list of orderable DB instance options for the specified engine.
-
#describe_pending_maintenance_actions(params = {}) ⇒ Types::PendingMaintenanceActionsMessage
Returns a list of resources (for example, DB instances) that have at least one pending maintenance action.
-
#describe_valid_db_instance_modifications(params = {}) ⇒ Types::DescribeValidDBInstanceModificationsResult
You can call DescribeValidDBInstanceModifications to learn what modifications you can make to your DB instance.
-
#failover_db_cluster(params = {}) ⇒ Types::FailoverDBClusterResult
Forces a failover for a DB cluster.
-
#failover_global_cluster(params = {}) ⇒ Types::FailoverGlobalClusterResult
Initiates the failover process for a Neptune global database.
-
#list_tags_for_resource(params = {}) ⇒ Types::TagListMessage
Lists all tags on an Amazon Neptune resource.
-
#modify_db_cluster(params = {}) ⇒ Types::ModifyDBClusterResult
Modify a setting for a DB cluster.
-
#modify_db_cluster_endpoint(params = {}) ⇒ Types::ModifyDBClusterEndpointOutput
Modifies the properties of an endpoint in an Amazon Neptune DB cluster.
-
#modify_db_cluster_parameter_group(params = {}) ⇒ Types::DBClusterParameterGroupNameMessage
Modifies the parameters of a DB cluster parameter group.
-
#modify_db_cluster_snapshot_attribute(params = {}) ⇒ Types::ModifyDBClusterSnapshotAttributeResult
Adds an attribute and values to, or removes an attribute and values from, a manual DB cluster snapshot.
-
#modify_db_instance(params = {}) ⇒ Types::ModifyDBInstanceResult
Modifies settings for a DB instance.
-
#modify_db_parameter_group(params = {}) ⇒ Types::DBParameterGroupNameMessage
Modifies the parameters of a DB parameter group.
-
#modify_db_subnet_group(params = {}) ⇒ Types::ModifyDBSubnetGroupResult
Modifies an existing DB subnet group.
-
#modify_event_subscription(params = {}) ⇒ Types::ModifyEventSubscriptionResult
Modifies an existing event notification subscription.
-
#modify_global_cluster(params = {}) ⇒ Types::ModifyGlobalClusterResult
Modify a setting for an Amazon Neptune global cluster.
-
#promote_read_replica_db_cluster(params = {}) ⇒ Types::PromoteReadReplicaDBClusterResult
Not supported.
-
#reboot_db_instance(params = {}) ⇒ Types::RebootDBInstanceResult
You might need to reboot your DB instance, usually for maintenance reasons.
-
#remove_from_global_cluster(params = {}) ⇒ Types::RemoveFromGlobalClusterResult
Detaches a Neptune DB cluster from a Neptune global database.
-
#remove_role_from_db_cluster(params = {}) ⇒ Struct
Disassociates an Identity and Access Management (IAM) role from a DB cluster.
-
#remove_source_identifier_from_subscription(params = {}) ⇒ Types::RemoveSourceIdentifierFromSubscriptionResult
Removes a source identifier from an existing event notification subscription.
-
#remove_tags_from_resource(params = {}) ⇒ Struct
Removes metadata tags from an Amazon Neptune resource.
-
#reset_db_cluster_parameter_group(params = {}) ⇒ Types::DBClusterParameterGroupNameMessage
Modifies the parameters of a DB cluster parameter group to the default value.
-
#reset_db_parameter_group(params = {}) ⇒ Types::DBParameterGroupNameMessage
Modifies the parameters of a DB parameter group to the engine/system default value.
-
#restore_db_cluster_from_snapshot(params = {}) ⇒ Types::RestoreDBClusterFromSnapshotResult
Creates a new DB cluster from a DB snapshot or DB cluster snapshot.
-
#restore_db_cluster_to_point_in_time(params = {}) ⇒ Types::RestoreDBClusterToPointInTimeResult
Restores a DB cluster to an arbitrary point in time.
-
#start_db_cluster(params = {}) ⇒ Types::StartDBClusterResult
Starts an Amazon Neptune DB cluster that was stopped using the Amazon console, the Amazon CLI stop-db-cluster command, or the StopDBCluster API.
-
#stop_db_cluster(params = {}) ⇒ Types::StopDBClusterResult
Stops an Amazon Neptune DB cluster.
-
#switchover_global_cluster(params = {}) ⇒ Types::SwitchoverGlobalClusterResult
Switches over the specified secondary DB cluster to be the new primary DB cluster in the global database cluster.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-neptune/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8049 8050 8051 |
# File 'lib/aws-sdk-neptune/client.rb', line 8049 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8052 8053 8054 |
# File 'lib/aws-sdk-neptune/client.rb', line 8052 def errors_module Errors end |
Instance Method Details
#add_role_to_db_cluster(params = {}) ⇒ Struct
Associates an Identity and Access Management (IAM) role with an Neptune DB cluster.
509 510 511 512 |
# File 'lib/aws-sdk-neptune/client.rb', line 509 def add_role_to_db_cluster(params = {}, = {}) req = build_request(:add_role_to_db_cluster, params) req.send_request() end |
#add_source_identifier_to_subscription(params = {}) ⇒ Types::AddSourceIdentifierToSubscriptionResult
Adds a source identifier to an existing event notification subscription.
568 569 570 571 |
# File 'lib/aws-sdk-neptune/client.rb', line 568 def add_source_identifier_to_subscription(params = {}, = {}) req = build_request(:add_source_identifier_to_subscription, params) req.send_request() end |
#add_tags_to_resource(params = {}) ⇒ Struct
Adds metadata tags to an Amazon Neptune resource. These tags can also be used with cost allocation reporting to track cost associated with Amazon Neptune resources, or used in a Condition statement in an IAM policy for Amazon Neptune.
608 609 610 611 |
# File 'lib/aws-sdk-neptune/client.rb', line 608 def (params = {}, = {}) req = build_request(:add_tags_to_resource, params) req.send_request() end |
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionResult
Applies a pending maintenance action to a resource (for example, to a DB instance).
671 672 673 674 |
# File 'lib/aws-sdk-neptune/client.rb', line 671 def apply_pending_maintenance_action(params = {}, = {}) req = build_request(:apply_pending_maintenance_action, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7907 7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 |
# File 'lib/aws-sdk-neptune/client.rb', line 7907 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Neptune') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-neptune' context[:gem_version] = '1.107.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_db_cluster_parameter_group(params = {}) ⇒ Types::CopyDBClusterParameterGroupResult
Copies the specified DB cluster parameter group.
748 749 750 751 |
# File 'lib/aws-sdk-neptune/client.rb', line 748 def copy_db_cluster_parameter_group(params = {}, = {}) req = build_request(:copy_db_cluster_parameter_group, params) req.send_request() end |
#copy_db_cluster_snapshot(params = {}) ⇒ Types::CopyDBClusterSnapshotResult
Copies a snapshot of a DB cluster.
To copy a DB cluster snapshot from a shared manual DB cluster snapshot, ‘SourceDBClusterSnapshotIdentifier` must be the Amazon Resource Name (ARN) of the shared DB cluster snapshot.
873 874 875 876 |
# File 'lib/aws-sdk-neptune/client.rb', line 873 def copy_db_cluster_snapshot(params = {}, = {}) req = build_request(:copy_db_cluster_snapshot, params) req.send_request() end |
#copy_db_parameter_group(params = {}) ⇒ Types::CopyDBParameterGroupResult
Copies the specified DB parameter group.
950 951 952 953 |
# File 'lib/aws-sdk-neptune/client.rb', line 950 def copy_db_parameter_group(params = {}, = {}) req = build_request(:copy_db_parameter_group, params) req.send_request() end |
#create_db_cluster(params = {}) ⇒ Types::CreateDBClusterResult
Creates a new Amazon Neptune DB cluster.
You can use the ‘ReplicationSourceIdentifier` parameter to create the DB cluster as a Read Replica of another DB cluster or Amazon Neptune DB instance.
Note that when you create a new cluster using ‘CreateDBCluster` directly, deletion protection is disabled by default (when you create a new production cluster in the console, deletion protection is enabled by default). You can only delete a DB cluster if its `DeletionProtection` field is set to `false`.
1340 1341 1342 1343 |
# File 'lib/aws-sdk-neptune/client.rb', line 1340 def create_db_cluster(params = {}, = {}) req = build_request(:create_db_cluster, params) req.send_request() end |
#create_db_cluster_endpoint(params = {}) ⇒ Types::CreateDBClusterEndpointOutput
Creates a new custom endpoint and associates it with an Amazon Neptune DB cluster.
1419 1420 1421 1422 |
# File 'lib/aws-sdk-neptune/client.rb', line 1419 def create_db_cluster_endpoint(params = {}, = {}) req = build_request(:create_db_cluster_endpoint, params) req.send_request() end |
#create_db_cluster_parameter_group(params = {}) ⇒ Types::CreateDBClusterParameterGroupResult
Creates a new DB cluster parameter group.
Parameters in a DB cluster parameter group apply to all of the instances in a DB cluster.
A DB cluster parameter group is initially created with the default parameters for the database engine used by instances in the DB cluster. To provide custom values for any of the parameters, you must modify the group after creating it using ModifyDBClusterParameterGroup. Once you’ve created a DB cluster parameter group, you need to associate it with your DB cluster using ModifyDBCluster. When you associate a new DB cluster parameter group with a running DB cluster, you need to reboot the DB instances in the DB cluster without failover for the new DB cluster parameter group and associated settings to take effect.
After you create a DB cluster parameter group, you should wait at least 5 minutes before creating your first DB cluster that uses that DB cluster parameter group as the default parameter group. This allows Amazon Neptune to fully complete the create action before the DB cluster parameter group is used as the default for a new DB cluster. This is especially important for parameters that are critical when creating the default database for a DB cluster, such as the character set for the default database defined by the ‘character_set_database` parameter. You can use the *Parameter Groups* option of the [Amazon Neptune console] or the DescribeDBClusterParameters command to verify that your DB cluster parameter group has been created or modified.
1512 1513 1514 1515 |
# File 'lib/aws-sdk-neptune/client.rb', line 1512 def create_db_cluster_parameter_group(params = {}, = {}) req = build_request(:create_db_cluster_parameter_group, params) req.send_request() end |
#create_db_cluster_snapshot(params = {}) ⇒ Types::CreateDBClusterSnapshotResult
Creates a snapshot of a DB cluster.
1594 1595 1596 1597 |
# File 'lib/aws-sdk-neptune/client.rb', line 1594 def create_db_cluster_snapshot(params = {}, = {}) req = build_request(:create_db_cluster_snapshot, params) req.send_request() end |
#create_db_instance(params = {}) ⇒ Types::CreateDBInstanceResult
Creates a new DB instance.
2051 2052 2053 2054 |
# File 'lib/aws-sdk-neptune/client.rb', line 2051 def create_db_instance(params = {}, = {}) req = build_request(:create_db_instance, params) req.send_request() end |
#create_db_parameter_group(params = {}) ⇒ Types::CreateDBParameterGroupResult
Creates a new DB parameter group.
A DB parameter group is initially created with the default parameters for the database engine used by the DB instance. To provide custom values for any of the parameters, you must modify the group after creating it using ModifyDBParameterGroup. Once you’ve created a DB parameter group, you need to associate it with your DB instance using ModifyDBInstance. When you associate a new DB parameter group with a running DB instance, you need to reboot the DB instance without failover for the new DB parameter group and associated settings to take effect.
After you create a DB parameter group, you should wait at least 5 minutes before creating your first DB instance that uses that DB parameter group as the default parameter group. This allows Amazon Neptune to fully complete the create action before the parameter group is used as the default for a new DB instance. This is especially important for parameters that are critical when creating the default database for a DB instance, such as the character set for the default database defined by the ‘character_set_database` parameter. You can use the *Parameter Groups* option of the Amazon Neptune console or the DescribeDBParameters command to verify that your DB parameter group has been created or modified.
2136 2137 2138 2139 |
# File 'lib/aws-sdk-neptune/client.rb', line 2136 def create_db_parameter_group(params = {}, = {}) req = build_request(:create_db_parameter_group, params) req.send_request() end |
#create_db_subnet_group(params = {}) ⇒ Types::CreateDBSubnetGroupResult
Creates a new DB subnet group. DB subnet groups must contain at least one subnet in at least two AZs in the Amazon Region.
2198 2199 2200 2201 |
# File 'lib/aws-sdk-neptune/client.rb', line 2198 def create_db_subnet_group(params = {}, = {}) req = build_request(:create_db_subnet_group, params) req.send_request() end |
#create_event_subscription(params = {}) ⇒ Types::CreateEventSubscriptionResult
Creates an event notification subscription. This action requires a topic ARN (Amazon Resource Name) created by either the Neptune console, the SNS console, or the SNS API. To obtain an ARN with SNS, you must create a topic in Amazon SNS and subscribe to the topic. The ARN is displayed in the SNS console.
You can specify the type of source (SourceType) you want to be notified of, provide a list of Neptune sources (SourceIds) that triggers the events, and provide a list of event categories (EventCategories) for events you want to be notified of. For example, you can specify SourceType = db-instance, SourceIds = mydbinstance1, mydbinstance2 and EventCategories = Availability, Backup.
If you specify both the SourceType and SourceIds, such as SourceType = db-instance and SourceIdentifier = myDBInstance1, you are notified of all the db-instance events for the specified source. If you specify a SourceType but do not specify a SourceIdentifier, you receive notice of the events for that source type for all your Neptune sources. If you do not specify either the SourceType nor the SourceIdentifier, you are notified of events generated from all Neptune sources belonging to your customer account.
2319 2320 2321 2322 |
# File 'lib/aws-sdk-neptune/client.rb', line 2319 def create_event_subscription(params = {}, = {}) req = build_request(:create_event_subscription, params) req.send_request() end |
#create_global_cluster(params = {}) ⇒ Types::CreateGlobalClusterResult
Creates a Neptune global database spread across multiple Amazon Regions. The global database contains a single primary cluster with read-write capability, and read-only secondary clusters that receive data from the primary cluster through high-speed replication performed by the Neptune storage subsystem.
You can create a global database that is initially empty, and then add a primary cluster and secondary clusters to it, or you can specify an existing Neptune cluster during the create operation to become the primary cluster of the global database.
2416 2417 2418 2419 |
# File 'lib/aws-sdk-neptune/client.rb', line 2416 def create_global_cluster(params = {}, = {}) req = build_request(:create_global_cluster, params) req.send_request() end |
#delete_db_cluster(params = {}) ⇒ Types::DeleteDBClusterResult
The DeleteDBCluster action deletes a previously provisioned DB cluster. When you delete a DB cluster, all automated backups for that DB cluster are deleted and can’t be recovered. Manual DB cluster snapshots of the specified DB cluster are not deleted.
Note that the DB Cluster cannot be deleted if deletion protection is enabled. To delete it, you must first set its ‘DeletionProtection` field to `False`.
2561 2562 2563 2564 |
# File 'lib/aws-sdk-neptune/client.rb', line 2561 def delete_db_cluster(params = {}, = {}) req = build_request(:delete_db_cluster, params) req.send_request() end |
#delete_db_cluster_endpoint(params = {}) ⇒ Types::DeleteDBClusterEndpointOutput
Deletes a custom endpoint and removes it from an Amazon Neptune DB cluster.
2611 2612 2613 2614 |
# File 'lib/aws-sdk-neptune/client.rb', line 2611 def delete_db_cluster_endpoint(params = {}, = {}) req = build_request(:delete_db_cluster_endpoint, params) req.send_request() end |
#delete_db_cluster_parameter_group(params = {}) ⇒ Struct
Deletes a specified DB cluster parameter group. The DB cluster parameter group to be deleted can’t be associated with any DB clusters.
2643 2644 2645 2646 |
# File 'lib/aws-sdk-neptune/client.rb', line 2643 def delete_db_cluster_parameter_group(params = {}, = {}) req = build_request(:delete_db_cluster_parameter_group, params) req.send_request() end |
#delete_db_cluster_snapshot(params = {}) ⇒ Types::DeleteDBClusterSnapshotResult
Deletes a DB cluster snapshot. If the snapshot is being copied, the copy operation is terminated.
<note markdown=“1”> The DB cluster snapshot must be in the ‘available` state to be deleted.
</note>
2701 2702 2703 2704 |
# File 'lib/aws-sdk-neptune/client.rb', line 2701 def delete_db_cluster_snapshot(params = {}, = {}) req = build_request(:delete_db_cluster_snapshot, params) req.send_request() end |
#delete_db_instance(params = {}) ⇒ Types::DeleteDBInstanceResult
The DeleteDBInstance action deletes a previously provisioned DB instance. When you delete a DB instance, all automated backups for that instance are deleted and can’t be recovered. Manual DB snapshots of the DB instance to be deleted by ‘DeleteDBInstance` are not deleted.
If you request a final DB snapshot the status of the Amazon Neptune DB instance is ‘deleting` until the DB snapshot is created. The API action `DescribeDBInstance` is used to monitor the status of this operation. The action can’t be canceled or reverted once submitted.
Note that when a DB instance is in a failure state and has a status of ‘failed`, `incompatible-restore`, or `incompatible-network`, you can only delete it when the `SkipFinalSnapshot` parameter is set to `true`.
You can’t delete a DB instance if it is the only instance in the DB cluster, or if it has deletion protection enabled.
2894 2895 2896 2897 |
# File 'lib/aws-sdk-neptune/client.rb', line 2894 def delete_db_instance(params = {}, = {}) req = build_request(:delete_db_instance, params) req.send_request() end |
#delete_db_parameter_group(params = {}) ⇒ Struct
Deletes a specified DBParameterGroup. The DBParameterGroup to be deleted can’t be associated with any DB instances.
2925 2926 2927 2928 |
# File 'lib/aws-sdk-neptune/client.rb', line 2925 def delete_db_parameter_group(params = {}, = {}) req = build_request(:delete_db_parameter_group, params) req.send_request() end |
#delete_db_subnet_group(params = {}) ⇒ Struct
Deletes a DB subnet group.
<note markdown=“1”> The specified database subnet group must not be associated with any DB instances.
</note>
2963 2964 2965 2966 |
# File 'lib/aws-sdk-neptune/client.rb', line 2963 def delete_db_subnet_group(params = {}, = {}) req = build_request(:delete_db_subnet_group, params) req.send_request() end |
#delete_event_subscription(params = {}) ⇒ Types::DeleteEventSubscriptionResult
Deletes an event notification subscription.
3002 3003 3004 3005 |
# File 'lib/aws-sdk-neptune/client.rb', line 3002 def delete_event_subscription(params = {}, = {}) req = build_request(:delete_event_subscription, params) req.send_request() end |
#delete_global_cluster(params = {}) ⇒ Types::DeleteGlobalClusterResult
Deletes a global database. The primary and all secondary clusters must already be detached or deleted first.
3051 3052 3053 3054 |
# File 'lib/aws-sdk-neptune/client.rb', line 3051 def delete_global_cluster(params = {}, = {}) req = build_request(:delete_global_cluster, params) req.send_request() end |
#describe_db_cluster_endpoints(params = {}) ⇒ Types::DBClusterEndpointMessage
Returns information about endpoints for an Amazon Neptune DB cluster.
<note markdown=“1”> This operation can also return information for Amazon RDS clusters and Amazon DocDB clusters.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3143 3144 3145 3146 |
# File 'lib/aws-sdk-neptune/client.rb', line 3143 def describe_db_cluster_endpoints(params = {}, = {}) req = build_request(:describe_db_cluster_endpoints, params) req.send_request() end |
#describe_db_cluster_parameter_groups(params = {}) ⇒ Types::DBClusterParameterGroupsMessage
Returns a list of ‘DBClusterParameterGroup` descriptions. If a `DBClusterParameterGroupName` parameter is specified, the list will contain only the description of the specified DB cluster parameter group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3217 3218 3219 3220 |
# File 'lib/aws-sdk-neptune/client.rb', line 3217 def describe_db_cluster_parameter_groups(params = {}, = {}) req = build_request(:describe_db_cluster_parameter_groups, params) req.send_request() end |
#describe_db_cluster_parameters(params = {}) ⇒ Types::DBClusterParameterGroupDetails
Returns the detailed parameter list for a particular DB cluster parameter group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3300 3301 3302 3303 |
# File 'lib/aws-sdk-neptune/client.rb', line 3300 def describe_db_cluster_parameters(params = {}, = {}) req = build_request(:describe_db_cluster_parameters, params) req.send_request() end |
#describe_db_cluster_snapshot_attributes(params = {}) ⇒ Types::DescribeDBClusterSnapshotAttributesResult
Returns a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot.
When sharing snapshots with other Amazon accounts, ‘DescribeDBClusterSnapshotAttributes` returns the `restore` attribute and a list of IDs for the Amazon accounts that are authorized to copy or restore the manual DB cluster snapshot. If `all` is included in the list of values for the `restore` attribute, then the manual DB cluster snapshot is public and can be copied or restored by all Amazon accounts.
To add or remove access for an Amazon account to copy or restore a manual DB cluster snapshot, or to make the manual DB cluster snapshot public or private, use the ModifyDBClusterSnapshotAttribute API action.
3347 3348 3349 3350 |
# File 'lib/aws-sdk-neptune/client.rb', line 3347 def describe_db_cluster_snapshot_attributes(params = {}, = {}) req = build_request(:describe_db_cluster_snapshot_attributes, params) req.send_request() end |
#describe_db_cluster_snapshots(params = {}) ⇒ Types::DBClusterSnapshotMessage
Returns information about DB cluster snapshots. This API action supports pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3500 3501 3502 3503 |
# File 'lib/aws-sdk-neptune/client.rb', line 3500 def describe_db_cluster_snapshots(params = {}, = {}) req = build_request(:describe_db_cluster_snapshots, params) req.send_request() end |
#describe_db_clusters(params = {}) ⇒ Types::DBClusterMessage
Returns information about provisioned DB clusters, and supports pagination.
<note markdown=“1”> This operation can also return information for Amazon RDS clusters and Amazon DocDB clusters.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3657 3658 3659 3660 |
# File 'lib/aws-sdk-neptune/client.rb', line 3657 def describe_db_clusters(params = {}, = {}) req = build_request(:describe_db_clusters, params) req.send_request() end |
#describe_db_engine_versions(params = {}) ⇒ Types::DBEngineVersionMessage
Returns a list of the available DB engines.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3773 3774 3775 3776 |
# File 'lib/aws-sdk-neptune/client.rb', line 3773 def describe_db_engine_versions(params = {}, = {}) req = build_request(:describe_db_engine_versions, params) req.send_request() end |
#describe_db_instances(params = {}) ⇒ Types::DBInstanceMessage
Returns information about provisioned instances, and supports pagination.
<note markdown=“1”> This operation can also return information for Amazon RDS instances and Amazon DocDB instances.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* db_instance_available
* db_instance_deleted
3967 3968 3969 3970 |
# File 'lib/aws-sdk-neptune/client.rb', line 3967 def describe_db_instances(params = {}, = {}) req = build_request(:describe_db_instances, params) req.send_request() end |
#describe_db_parameter_groups(params = {}) ⇒ Types::DBParameterGroupsMessage
Returns a list of ‘DBParameterGroup` descriptions. If a `DBParameterGroupName` is specified, the list will contain only the description of the specified DB parameter group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4039 4040 4041 4042 |
# File 'lib/aws-sdk-neptune/client.rb', line 4039 def describe_db_parameter_groups(params = {}, = {}) req = build_request(:describe_db_parameter_groups, params) req.send_request() end |
#describe_db_parameters(params = {}) ⇒ Types::DBParameterGroupDetails
Returns the detailed parameter list for a particular DB parameter group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4123 4124 4125 4126 |
# File 'lib/aws-sdk-neptune/client.rb', line 4123 def describe_db_parameters(params = {}, = {}) req = build_request(:describe_db_parameters, params) req.send_request() end |
#describe_db_subnet_groups(params = {}) ⇒ Types::DBSubnetGroupMessage
Returns a list of DBSubnetGroup descriptions. If a DBSubnetGroupName is specified, the list will contain only the descriptions of the specified DBSubnetGroup.
For an overview of CIDR ranges, go to the [Wikipedia Tutorial].
[1]: en.wikipedia.org/wiki/Classless_Inter-Domain_Routing
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4201 4202 4203 4204 |
# File 'lib/aws-sdk-neptune/client.rb', line 4201 def describe_db_subnet_groups(params = {}, = {}) req = build_request(:describe_db_subnet_groups, params) req.send_request() end |
#describe_engine_default_cluster_parameters(params = {}) ⇒ Types::DescribeEngineDefaultClusterParametersResult
Returns the default engine and system parameter information for the cluster database engine.
4270 4271 4272 4273 |
# File 'lib/aws-sdk-neptune/client.rb', line 4270 def describe_engine_default_cluster_parameters(params = {}, = {}) req = build_request(:describe_engine_default_cluster_parameters, params) req.send_request() end |
#describe_engine_default_parameters(params = {}) ⇒ Types::DescribeEngineDefaultParametersResult
Returns the default engine and system parameter information for the specified database engine.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4340 4341 4342 4343 |
# File 'lib/aws-sdk-neptune/client.rb', line 4340 def describe_engine_default_parameters(params = {}, = {}) req = build_request(:describe_engine_default_parameters, params) req.send_request() end |
#describe_event_categories(params = {}) ⇒ Types::EventCategoriesMessage
Displays a list of categories for all event source types, or, if specified, for a specified source type.
4384 4385 4386 4387 |
# File 'lib/aws-sdk-neptune/client.rb', line 4384 def describe_event_categories(params = {}, = {}) req = build_request(:describe_event_categories, params) req.send_request() end |
#describe_event_subscriptions(params = {}) ⇒ Types::EventSubscriptionsMessage
Lists all the subscription descriptions for a customer account. The description for a subscription includes SubscriptionName, SNSTopicARN, CustomerID, SourceType, SourceID, CreationTime, and Status.
If you specify a SubscriptionName, lists the description for that subscription.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4460 4461 4462 4463 |
# File 'lib/aws-sdk-neptune/client.rb', line 4460 def describe_event_subscriptions(params = {}, = {}) req = build_request(:describe_event_subscriptions, params) req.send_request() end |
#describe_events(params = {}) ⇒ Types::EventsMessage
Returns events related to DB instances, DB security groups, DB snapshots, and DB parameter groups for the past 14 days. Events specific to a particular DB instance, DB security group, database snapshot, or DB parameter group can be obtained by providing the name as a parameter. By default, the past hour of events are returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4588 4589 4590 4591 |
# File 'lib/aws-sdk-neptune/client.rb', line 4588 def describe_events(params = {}, = {}) req = build_request(:describe_events, params) req.send_request() end |
#describe_global_clusters(params = {}) ⇒ Types::GlobalClustersMessage
Returns information about Neptune global database clusters. This API supports pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4665 4666 4667 4668 |
# File 'lib/aws-sdk-neptune/client.rb', line 4665 def describe_global_clusters(params = {}, = {}) req = build_request(:describe_global_clusters, params) req.send_request() end |
#describe_orderable_db_instance_options(params = {}) ⇒ Types::OrderableDBInstanceOptionsMessage
Returns a list of orderable DB instance options for the specified engine.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4769 4770 4771 4772 |
# File 'lib/aws-sdk-neptune/client.rb', line 4769 def (params = {}, = {}) req = build_request(:describe_orderable_db_instance_options, params) req.send_request() end |
#describe_pending_maintenance_actions(params = {}) ⇒ Types::PendingMaintenanceActionsMessage
Returns a list of resources (for example, DB instances) that have at least one pending maintenance action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4849 4850 4851 4852 |
# File 'lib/aws-sdk-neptune/client.rb', line 4849 def describe_pending_maintenance_actions(params = {}, = {}) req = build_request(:describe_pending_maintenance_actions, params) req.send_request() end |
#describe_valid_db_instance_modifications(params = {}) ⇒ Types::DescribeValidDBInstanceModificationsResult
You can call DescribeValidDBInstanceModifications to learn what modifications you can make to your DB instance. You can use this information when you call ModifyDBInstance.
4891 4892 4893 4894 |
# File 'lib/aws-sdk-neptune/client.rb', line 4891 def describe_valid_db_instance_modifications(params = {}, = {}) req = build_request(:describe_valid_db_instance_modifications, params) req.send_request() end |
#failover_db_cluster(params = {}) ⇒ Types::FailoverDBClusterResult
Forces a failover for a DB cluster.
A failover for a DB cluster promotes one of the Read Replicas (read-only instances) in the DB cluster to be the primary instance (the cluster writer).
Amazon Neptune will automatically fail over to a Read Replica, if one exists, when the primary instance fails. You can force a failover when you want to simulate a failure of a primary instance for testing. Because each instance in a DB cluster has its own endpoint address, you will need to clean up and re-establish any existing connections that use those endpoint addresses when the failover is complete.
5015 5016 5017 5018 |
# File 'lib/aws-sdk-neptune/client.rb', line 5015 def failover_db_cluster(params = {}, = {}) req = build_request(:failover_db_cluster, params) req.send_request() end |
#failover_global_cluster(params = {}) ⇒ Types::FailoverGlobalClusterResult
Initiates the failover process for a Neptune global database.
A failover for a Neptune global database promotes one of secondary read-only DB clusters to be the primary DB cluster and demotes the primary DB cluster to being a secondary (read-only) DB cluster. In other words, the role of the current primary DB cluster and the selected target secondary DB cluster are switched. The selected secondary DB cluster assumes full read/write capabilities for the Neptune global database.
<note markdown=“1”> This action applies only to Neptune global databases. This action is only intended for use on healthy Neptune global databases with healthy Neptune DB clusters and no region-wide outages, to test disaster recovery scenarios or to reconfigure the global database topology.
</note>
5108 5109 5110 5111 |
# File 'lib/aws-sdk-neptune/client.rb', line 5108 def failover_global_cluster(params = {}, = {}) req = build_request(:failover_global_cluster, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::TagListMessage
Lists all tags on an Amazon Neptune resource.
5153 5154 5155 5156 |
# File 'lib/aws-sdk-neptune/client.rb', line 5153 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#modify_db_cluster(params = {}) ⇒ Types::ModifyDBClusterResult
Modify a setting for a DB cluster. You can change one or more database configuration parameters by specifying these parameters and the new values in the request.
5487 5488 5489 5490 |
# File 'lib/aws-sdk-neptune/client.rb', line 5487 def modify_db_cluster(params = {}, = {}) req = build_request(:modify_db_cluster, params) req.send_request() end |
#modify_db_cluster_endpoint(params = {}) ⇒ Types::ModifyDBClusterEndpointOutput
Modifies the properties of an endpoint in an Amazon Neptune DB cluster.
5552 5553 5554 5555 |
# File 'lib/aws-sdk-neptune/client.rb', line 5552 def modify_db_cluster_endpoint(params = {}, = {}) req = build_request(:modify_db_cluster_endpoint, params) req.send_request() end |
#modify_db_cluster_parameter_group(params = {}) ⇒ Types::DBClusterParameterGroupNameMessage
Modifies the parameters of a DB cluster parameter group. To modify more than one parameter, submit a list of the following: ‘ParameterName`, `ParameterValue`, and `ApplyMethod`. A maximum of 20 parameters can be modified in a single request.
<note markdown=“1”> Changes to dynamic parameters are applied immediately. Changes to static parameters require a reboot without failover to the DB cluster associated with the parameter group before the change can take effect.
</note>
After you create a DB cluster parameter group, you should wait at least 5 minutes before creating your first DB cluster that uses that DB cluster parameter group as the default parameter group. This allows Amazon Neptune to fully complete the create action before the parameter group is used as the default for a new DB cluster. This is especially important for parameters that are critical when creating the default database for a DB cluster, such as the character set for the default database defined by the ‘character_set_database` parameter. You can use the *Parameter Groups* option of the Amazon Neptune console or the DescribeDBClusterParameters command to verify that your DB cluster parameter group has been created or modified.
5618 5619 5620 5621 |
# File 'lib/aws-sdk-neptune/client.rb', line 5618 def modify_db_cluster_parameter_group(params = {}, = {}) req = build_request(:modify_db_cluster_parameter_group, params) req.send_request() end |
#modify_db_cluster_snapshot_attribute(params = {}) ⇒ Types::ModifyDBClusterSnapshotAttributeResult
Adds an attribute and values to, or removes an attribute and values from, a manual DB cluster snapshot.
To share a manual DB cluster snapshot with other Amazon accounts, specify ‘restore` as the `AttributeName` and use the `ValuesToAdd` parameter to add a list of IDs of the Amazon accounts that are authorized to restore the manual DB cluster snapshot. Use the value `all` to make the manual DB cluster snapshot public, which means that it can be copied or restored by all Amazon accounts. Do not add the `all` value for any manual DB cluster snapshots that contain private information that you don’t want available to all Amazon accounts. If a manual DB cluster snapshot is encrypted, it can be shared, but only by specifying a list of authorized Amazon account IDs for the ‘ValuesToAdd` parameter. You can’t use ‘all` as a value for that parameter in this case.
To view which Amazon accounts have access to copy or restore a manual DB cluster snapshot, or whether a manual DB cluster snapshot public or private, use the DescribeDBClusterSnapshotAttributes API action.
5701 5702 5703 5704 |
# File 'lib/aws-sdk-neptune/client.rb', line 5701 def modify_db_cluster_snapshot_attribute(params = {}, = {}) req = build_request(:modify_db_cluster_snapshot_attribute, params) req.send_request() end |
#modify_db_instance(params = {}) ⇒ Types::ModifyDBInstanceResult
Modifies settings for a DB instance. You can change one or more database configuration parameters by specifying these parameters and the new values in the request. To learn what modifications you can make to your DB instance, call DescribeValidDBInstanceModifications before you call ModifyDBInstance.
6172 6173 6174 6175 |
# File 'lib/aws-sdk-neptune/client.rb', line 6172 def modify_db_instance(params = {}, = {}) req = build_request(:modify_db_instance, params) req.send_request() end |
#modify_db_parameter_group(params = {}) ⇒ Types::DBParameterGroupNameMessage
Modifies the parameters of a DB parameter group. To modify more than one parameter, submit a list of the following: ‘ParameterName`, `ParameterValue`, and `ApplyMethod`. A maximum of 20 parameters can be modified in a single request.
<note markdown=“1”> Changes to dynamic parameters are applied immediately. Changes to static parameters require a reboot without failover to the DB instance associated with the parameter group before the change can take effect.
</note>
After you modify a DB parameter group, you should wait at least 5 minutes before creating your first DB instance that uses that DB parameter group as the default parameter group. This allows Amazon Neptune to fully complete the modify action before the parameter group is used as the default for a new DB instance. This is especially important for parameters that are critical when creating the default database for a DB instance, such as the character set for the default database defined by the ‘character_set_database` parameter. You can use the *Parameter Groups* option of the Amazon Neptune console or the DescribeDBParameters command to verify that your DB parameter group has been created or modified.
6257 6258 6259 6260 |
# File 'lib/aws-sdk-neptune/client.rb', line 6257 def modify_db_parameter_group(params = {}, = {}) req = build_request(:modify_db_parameter_group, params) req.send_request() end |
#modify_db_subnet_group(params = {}) ⇒ Types::ModifyDBSubnetGroupResult
Modifies an existing DB subnet group. DB subnet groups must contain at least one subnet in at least two AZs in the Amazon Region.
6310 6311 6312 6313 |
# File 'lib/aws-sdk-neptune/client.rb', line 6310 def modify_db_subnet_group(params = {}, = {}) req = build_request(:modify_db_subnet_group, params) req.send_request() end |
#modify_event_subscription(params = {}) ⇒ Types::ModifyEventSubscriptionResult
Modifies an existing event notification subscription. Note that you can’t modify the source identifiers using this call; to change source identifiers for a subscription, use the AddSourceIdentifierToSubscription and RemoveSourceIdentifierFromSubscription calls.
You can see a list of the event categories for a given SourceType by using the DescribeEventCategories action.
6382 6383 6384 6385 |
# File 'lib/aws-sdk-neptune/client.rb', line 6382 def modify_event_subscription(params = {}, = {}) req = build_request(:modify_event_subscription, params) req.send_request() end |
#modify_global_cluster(params = {}) ⇒ Types::ModifyGlobalClusterResult
Modify a setting for an Amazon Neptune global cluster. You can change one or more database configuration parameters by specifying these parameters and their new values in the request.
6480 6481 6482 6483 |
# File 'lib/aws-sdk-neptune/client.rb', line 6480 def modify_global_cluster(params = {}, = {}) req = build_request(:modify_global_cluster, params) req.send_request() end |
#promote_read_replica_db_cluster(params = {}) ⇒ Types::PromoteReadReplicaDBClusterResult
Not supported.
6579 6580 6581 6582 |
# File 'lib/aws-sdk-neptune/client.rb', line 6579 def promote_read_replica_db_cluster(params = {}, = {}) req = build_request(:promote_read_replica_db_cluster, params) req.send_request() end |
#reboot_db_instance(params = {}) ⇒ Types::RebootDBInstanceResult
You might need to reboot your DB instance, usually for maintenance reasons. For example, if you make certain modifications, or if you change the DB parameter group associated with the DB instance, you must reboot the instance for the changes to take effect.
Rebooting a DB instance restarts the database engine service. Rebooting a DB instance results in a momentary outage, during which the DB instance status is set to rebooting.
6728 6729 6730 6731 |
# File 'lib/aws-sdk-neptune/client.rb', line 6728 def reboot_db_instance(params = {}, = {}) req = build_request(:reboot_db_instance, params) req.send_request() end |
#remove_from_global_cluster(params = {}) ⇒ Types::RemoveFromGlobalClusterResult
Detaches a Neptune DB cluster from a Neptune global database. A secondary cluster becomes a normal standalone cluster with read-write capability instead of being read-only, and no longer receives data from the primary cluster.
6785 6786 6787 6788 |
# File 'lib/aws-sdk-neptune/client.rb', line 6785 def remove_from_global_cluster(params = {}, = {}) req = build_request(:remove_from_global_cluster, params) req.send_request() end |
#remove_role_from_db_cluster(params = {}) ⇒ Struct
Disassociates an Identity and Access Management (IAM) role from a DB cluster.
6820 6821 6822 6823 |
# File 'lib/aws-sdk-neptune/client.rb', line 6820 def remove_role_from_db_cluster(params = {}, = {}) req = build_request(:remove_role_from_db_cluster, params) req.send_request() end |
#remove_source_identifier_from_subscription(params = {}) ⇒ Types::RemoveSourceIdentifierFromSubscriptionResult
Removes a source identifier from an existing event notification subscription.
6867 6868 6869 6870 |
# File 'lib/aws-sdk-neptune/client.rb', line 6867 def remove_source_identifier_from_subscription(params = {}, = {}) req = build_request(:remove_source_identifier_from_subscription, params) req.send_request() end |
#remove_tags_from_resource(params = {}) ⇒ Struct
Removes metadata tags from an Amazon Neptune resource.
6899 6900 6901 6902 |
# File 'lib/aws-sdk-neptune/client.rb', line 6899 def (params = {}, = {}) req = build_request(:remove_tags_from_resource, params) req.send_request() end |
#reset_db_cluster_parameter_group(params = {}) ⇒ Types::DBClusterParameterGroupNameMessage
Modifies the parameters of a DB cluster parameter group to the default value. To reset specific parameters submit a list of the following: ‘ParameterName` and `ApplyMethod`. To reset the entire DB cluster parameter group, specify the `DBClusterParameterGroupName` and `ResetAllParameters` parameters.
When resetting the entire group, dynamic parameters are updated immediately and static parameters are set to ‘pending-reboot` to take effect on the next DB instance restart or RebootDBInstance request. You must call RebootDBInstance for every DB instance in your DB cluster that you want the updated static parameter to apply to.
6963 6964 6965 6966 |
# File 'lib/aws-sdk-neptune/client.rb', line 6963 def reset_db_cluster_parameter_group(params = {}, = {}) req = build_request(:reset_db_cluster_parameter_group, params) req.send_request() end |
#reset_db_parameter_group(params = {}) ⇒ Types::DBParameterGroupNameMessage
Modifies the parameters of a DB parameter group to the engine/system default value. To reset specific parameters, provide a list of the following: ‘ParameterName` and `ApplyMethod`. To reset the entire DB parameter group, specify the `DBParameterGroup` name and `ResetAllParameters` parameters. When resetting the entire group, dynamic parameters are updated immediately and static parameters are set to `pending-reboot` to take effect on the next DB instance restart or `RebootDBInstance` request.
7034 7035 7036 7037 |
# File 'lib/aws-sdk-neptune/client.rb', line 7034 def reset_db_parameter_group(params = {}, = {}) req = build_request(:reset_db_parameter_group, params) req.send_request() end |
#restore_db_cluster_from_snapshot(params = {}) ⇒ Types::RestoreDBClusterFromSnapshotResult
Creates a new DB cluster from a DB snapshot or DB cluster snapshot.
If a DB snapshot is specified, the target DB cluster is created from the source DB snapshot with a default configuration and default security group.
If a DB cluster snapshot is specified, the target DB cluster is created from the source DB cluster restore point with the same configuration as the original source DB cluster, except that the new DB cluster is created with the default security group.
7314 7315 7316 7317 |
# File 'lib/aws-sdk-neptune/client.rb', line 7314 def restore_db_cluster_from_snapshot(params = {}, = {}) req = build_request(:restore_db_cluster_from_snapshot, params) req.send_request() end |
#restore_db_cluster_to_point_in_time(params = {}) ⇒ Types::RestoreDBClusterToPointInTimeResult
Restores a DB cluster to an arbitrary point in time. Users can restore to any point in time before ‘LatestRestorableTime` for up to `BackupRetentionPeriod` days. The target DB cluster is created from the source DB cluster with the same configuration as the original DB cluster, except that the new DB cluster is created with the default DB security group.
<note markdown=“1”> This action only restores the DB cluster, not the DB instances for that DB cluster. You must invoke the CreateDBInstance action to create DB instances for the restored DB cluster, specifying the identifier of the restored DB cluster in ‘DBClusterIdentifier`. You can create DB instances only after the `RestoreDBClusterToPointInTime` action has completed and the DB cluster is available.
</note>
7617 7618 7619 7620 |
# File 'lib/aws-sdk-neptune/client.rb', line 7617 def restore_db_cluster_to_point_in_time(params = {}, = {}) req = build_request(:restore_db_cluster_to_point_in_time, params) req.send_request() end |
#start_db_cluster(params = {}) ⇒ Types::StartDBClusterResult
Starts an Amazon Neptune DB cluster that was stopped using the Amazon console, the Amazon CLI stop-db-cluster command, or the StopDBCluster API.
7719 7720 7721 7722 |
# File 'lib/aws-sdk-neptune/client.rb', line 7719 def start_db_cluster(params = {}, = {}) req = build_request(:start_db_cluster, params) req.send_request() end |
#stop_db_cluster(params = {}) ⇒ Types::StopDBClusterResult
Stops an Amazon Neptune DB cluster. When you stop a DB cluster, Neptune retains the DB cluster’s metadata, including its endpoints and DB parameter groups.
Neptune also retains the transaction logs so you can do a point-in-time restore if necessary.
7824 7825 7826 7827 |
# File 'lib/aws-sdk-neptune/client.rb', line 7824 def stop_db_cluster(params = {}, = {}) req = build_request(:stop_db_cluster, params) req.send_request() end |
#switchover_global_cluster(params = {}) ⇒ Types::SwitchoverGlobalClusterResult
Switches over the specified secondary DB cluster to be the new primary DB cluster in the global database cluster. Switchover operations were previously called “managed planned failovers.”
Promotes the specified secondary cluster to assume full read/write capabilities and demotes the current primary cluster to a secondary (read-only) cluster, maintaining the original replication topology. All secondary clusters are synchronized with the primary at the beginning of the process so the new primary continues operations for the global database without losing any data. Your database is unavailable for a short time while the primary and selected secondary clusters are assuming their new roles.
<note markdown=“1”> This operation is intended for controlled environments, for operations such as “regional rotation” or to fall back to the original primary after a global database failover.
</note>
7898 7899 7900 7901 |
# File 'lib/aws-sdk-neptune/client.rb', line 7898 def switchover_global_cluster(params = {}, = {}) req = build_request(:switchover_global_cluster, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ——————— | —————————— | ——– | ————- | | db_instance_available | #describe_db_instances | 30 | 60 | | db_instance_deleted | #describe_db_instances | 30 | 60 |
8014 8015 8016 8017 8018 |
# File 'lib/aws-sdk-neptune/client.rb', line 8014 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8022 8023 8024 |
# File 'lib/aws-sdk-neptune/client.rb', line 8022 def waiter_names waiters.keys end |