Class: Aws::Neptune::Types::CreateGlobalClusterMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::CreateGlobalClusterMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database_name ⇒ String
The name for the new global database (up to 64 alpha-numeric characters..
-
#deletion_protection ⇒ Boolean
The deletion protection setting for the new global database.
-
#engine ⇒ String
The name of the database engine to be used in the global database.
-
#engine_version ⇒ String
The Neptune engine version to be used by the global database.
-
#global_cluster_identifier ⇒ String
The cluster identifier of the new global database cluster.
-
#source_db_cluster_identifier ⇒ String
(Optional) The Amazon Resource Name (ARN) of an existing Neptune DB cluster to use as the primary cluster of the new global database.
-
#storage_encrypted ⇒ Boolean
The storage encryption setting for the new global database cluster.
-
#tags ⇒ Array<Types::Tag>
Tags to assign to the global cluster.
Instance Attribute Details
#database_name ⇒ String
The name for the new global database (up to 64 alpha-numeric characters.
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-neptune/types.rb', line 1750 class CreateGlobalClusterMessage < Struct.new( :global_cluster_identifier, :source_db_cluster_identifier, :engine, :engine_version, :deletion_protection, :database_name, :tags, :storage_encrypted) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ Boolean
The deletion protection setting for the new global database. The global database can’t be deleted when deletion protection is enabled.
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-neptune/types.rb', line 1750 class CreateGlobalClusterMessage < Struct.new( :global_cluster_identifier, :source_db_cluster_identifier, :engine, :engine_version, :deletion_protection, :database_name, :tags, :storage_encrypted) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the database engine to be used in the global database.
Valid values: neptune
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-neptune/types.rb', line 1750 class CreateGlobalClusterMessage < Struct.new( :global_cluster_identifier, :source_db_cluster_identifier, :engine, :engine_version, :deletion_protection, :database_name, :tags, :storage_encrypted) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The Neptune engine version to be used by the global database.
Valid values: 1.2.0.0 or above.
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-neptune/types.rb', line 1750 class CreateGlobalClusterMessage < Struct.new( :global_cluster_identifier, :source_db_cluster_identifier, :engine, :engine_version, :deletion_protection, :database_name, :tags, :storage_encrypted) SENSITIVE = [] include Aws::Structure end |
#global_cluster_identifier ⇒ String
The cluster identifier of the new global database cluster.
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-neptune/types.rb', line 1750 class CreateGlobalClusterMessage < Struct.new( :global_cluster_identifier, :source_db_cluster_identifier, :engine, :engine_version, :deletion_protection, :database_name, :tags, :storage_encrypted) SENSITIVE = [] include Aws::Structure end |
#source_db_cluster_identifier ⇒ String
(Optional) The Amazon Resource Name (ARN) of an existing Neptune DB cluster to use as the primary cluster of the new global database.
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-neptune/types.rb', line 1750 class CreateGlobalClusterMessage < Struct.new( :global_cluster_identifier, :source_db_cluster_identifier, :engine, :engine_version, :deletion_protection, :database_name, :tags, :storage_encrypted) SENSITIVE = [] include Aws::Structure end |
#storage_encrypted ⇒ Boolean
The storage encryption setting for the new global database cluster.
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-neptune/types.rb', line 1750 class CreateGlobalClusterMessage < Struct.new( :global_cluster_identifier, :source_db_cluster_identifier, :engine, :engine_version, :deletion_protection, :database_name, :tags, :storage_encrypted) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags to assign to the global cluster.
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-neptune/types.rb', line 1750 class CreateGlobalClusterMessage < Struct.new( :global_cluster_identifier, :source_db_cluster_identifier, :engine, :engine_version, :deletion_protection, :database_name, :tags, :storage_encrypted) SENSITIVE = [] include Aws::Structure end |