Class: Aws::Neptune::Types::DeleteDBClusterEndpointOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::DeleteDBClusterEndpointOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
This data type represents the information you need to connect to an Amazon Neptune DB cluster. This data type is used as a response element in the following actions:
-
‘CreateDBClusterEndpoint`
-
‘DescribeDBClusterEndpoints`
-
‘ModifyDBClusterEndpoint`
-
‘DeleteDBClusterEndpoint`
For the data structure that represents Amazon RDS DB instance endpoints, see ‘Endpoint`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_endpoint_type ⇒ String
The type associated with a custom endpoint.
-
#db_cluster_endpoint_arn ⇒ String
The Amazon Resource Name (ARN) for the endpoint.
-
#db_cluster_endpoint_identifier ⇒ String
The identifier associated with the endpoint.
-
#db_cluster_endpoint_resource_identifier ⇒ String
A unique system-generated identifier for an endpoint.
-
#db_cluster_identifier ⇒ String
The DB cluster identifier of the DB cluster associated with the endpoint.
-
#endpoint ⇒ String
The DNS address of the endpoint.
-
#endpoint_type ⇒ String
The type of the endpoint.
-
#excluded_members ⇒ Array<String>
List of DB instance identifiers that aren’t part of the custom endpoint group.
-
#static_members ⇒ Array<String>
List of DB instance identifiers that are part of the custom endpoint group.
-
#status ⇒ String
The current status of the endpoint.
Instance Attribute Details
#custom_endpoint_type ⇒ String
The type associated with a custom endpoint. One of: ‘READER`, `WRITER`, `ANY`.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#db_cluster_endpoint_arn ⇒ String
The Amazon Resource Name (ARN) for the endpoint.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#db_cluster_endpoint_identifier ⇒ String
The identifier associated with the endpoint. This parameter is stored as a lowercase string.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#db_cluster_endpoint_resource_identifier ⇒ String
A unique system-generated identifier for an endpoint. It remains the same for the whole life of the endpoint.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
The DB cluster identifier of the DB cluster associated with the endpoint. This parameter is stored as a lowercase string.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The DNS address of the endpoint.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#endpoint_type ⇒ String
The type of the endpoint. One of: ‘READER`, `WRITER`, `CUSTOM`.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#excluded_members ⇒ Array<String>
List of DB instance identifiers that aren’t part of the custom endpoint group. All other eligible instances are reachable through the custom endpoint. Only relevant if the list of static members is empty.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#static_members ⇒ Array<String>
List of DB instance identifiers that are part of the custom endpoint group.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the endpoint. One of: ‘creating`, `available`, `deleting`, `inactive`, `modifying`. The `inactive` state applies to an endpoint that cannot be used for a certain kind of cluster, such as a `writer` endpoint for a read-only secondary cluster in a global database.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-neptune/types.rb', line 3612 class DeleteDBClusterEndpointOutput < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |