Class: Aws::Neptune::Types::PendingModifiedValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::Neptune::Types::PendingModifiedValues
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptune/types.rb
Overview
This data type is used as a response element in the ModifyDBInstance action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
Contains the new
AllocatedStoragesize for the DB instance that will be applied or is currently being applied. -
#backup_retention_period ⇒ Integer
Specifies the pending number of days for which automated backups are retained.
-
#ca_certificate_identifier ⇒ String
Specifies the identifier of the CA certificate for the DB instance.
-
#db_instance_class ⇒ String
Contains the new
DBInstanceClassfor the DB instance that will be applied or is currently being applied. -
#db_instance_identifier ⇒ String
Contains the new
DBInstanceIdentifierfor the DB instance that will be applied or is currently being applied. -
#db_subnet_group_name ⇒ String
The new DB subnet group for the DB instance.
-
#engine_version ⇒ String
Indicates the database engine version.
-
#iops ⇒ Integer
Specifies the new Provisioned IOPS value for the DB instance that will be applied or is currently being applied.
-
#license_model ⇒ String
Not supported by Neptune.
-
#master_user_password ⇒ String
Not supported by Neptune.
-
#multi_az ⇒ Boolean
Indicates that the Single-AZ DB instance is to change to a Multi-AZ deployment.
-
#pending_cloudwatch_logs_exports ⇒ Types::PendingCloudwatchLogsExports
This
PendingCloudwatchLogsExportsstructure specifies pending changes to which CloudWatch logs are enabled and which are disabled. -
#port ⇒ Integer
Specifies the pending port for the DB instance.
-
#storage_type ⇒ String
Not applicable.
Instance Attribute Details
#allocated_storage ⇒ Integer
Contains the new AllocatedStorage size for the DB instance that will be applied or is currently being applied.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#backup_retention_period ⇒ Integer
Specifies the pending number of days for which automated backups are retained.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#ca_certificate_identifier ⇒ String
Specifies the identifier of the CA certificate for the DB instance.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#db_instance_class ⇒ String
Contains the new DBInstanceClass for the DB instance that will be applied or is currently being applied.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#db_instance_identifier ⇒ String
Contains the new DBInstanceIdentifier for the DB instance that will be applied or is currently being applied.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#db_subnet_group_name ⇒ String
The new DB subnet group for the DB instance.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
Indicates the database engine version.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
Specifies the new Provisioned IOPS value for the DB instance that will be applied or is currently being applied.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#license_model ⇒ String
Not supported by Neptune.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#master_user_password ⇒ String
Not supported by Neptune.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#multi_az ⇒ Boolean
Indicates that the Single-AZ DB instance is to change to a Multi-AZ deployment.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#pending_cloudwatch_logs_exports ⇒ Types::PendingCloudwatchLogsExports
This PendingCloudwatchLogsExports structure specifies pending changes to which CloudWatch logs are enabled and which are disabled.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
Specifies the pending port for the DB instance.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
Not applicable. In Neptune the storage type is managed at the DB Cluster level.
7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-neptune/types.rb', line 7192 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports) SENSITIVE = [] include Aws::Structure end |